/**************************************************************************
 |                                                                         
 |                    STATA SETUP FILE FOR ICPSR 03023
 |             COOPERATIVE AGREEMENT FOR AIDS COMMUNITY-BASED
 |           OUTREACH/INTERVENTION RESEARCH PROGRAM, 1992-1998
 |                      (DATASET 0002: PROCESS DATA)
 |
 |
 |  Please edit this file as instructed below.
 |  To execute, start Stata, change to the directory containing:
 |       - this do file
 |       - the ASCII data file
 |       - the dictionary file
 |
 |  Then execute the do file (e.g., do 03023-0002-statasetup.do)
 |
 **************************************************************************/

set mem 6m  /* Allocating 6 megabyte(s) of RAM for Stata SE to read the
                 data file into memory. */


set more off  /* This prevents the Stata output viewer from pausing the
                 process */

/****************************************************

Section 1: File Specifications
   This section assigns local macros to the necessary files.
   Please edit:
        "data-filename" ==> The name of data file downloaded from ICPSR
        "dictionary-filename" ==> The name of the dictionary file downloaded.
        "stata-datafile" ==> The name you wish to call your Stata data file.

   Note:  We assume that the raw data, dictionary, and setup (this do file) all
          reside in the same directory (or folder).  If that is not the case
          you will need to include paths as well as filenames in the macros.

********************************************************/

local raw_data "data-filename"
local dict "dictionary-filename"
local outfile "stata-datafile"

/********************************************************

Section 2: Infile Command

This section reads the raw data into Stata format.  If Section 1 was defined
properly, there should be no reason to modify this section.  These macros
should inflate automatically.

**********************************************************/

infile using `dict', using (`raw_data') clear


/*********************************************************

Section 3: Value Label Definitions
This section defines labels for the individual values of each variable.
We suggest that users do not modify this section.

**********************************************************/


label data "Cooperative Agreement for AIDS Community-Based Outreach/Intervention Research Program, 1992-1998, Dataset 0002"

#delimit ;
label define SITECODE  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SI1       -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI2       -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI3       -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI4       -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI5       -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI6_1     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SI6_2     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SI7_1     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SI7_2     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SI7_3     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SI7_4     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SI7_5     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SI8       -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SI9       -9.0 "-9 = SKIP, INELIG, NA" -8.0 "-8 = REFUSED"
                       -7.0 "-7 = DO NOT KNOW, UNSURE"
                       -6.0 "-6 = NOT APPLIC OR REFUSED"
                       -5.0 "-5 = SYSTEM MISSING" -4.0 "-4 = INVALID VALUE" ;
label define SI10_1    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SI10B_2   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SI11      -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SI12_1    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SI12_2    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SI13      -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SI14      -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NEVER" 1 "1=SOME" 2 "2=ALWAYS" ;
label define SI15      -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NEVER" 1 "1=SOME" 2 "2=ALWAYS" ;
label define SI16      -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NEVER" 1 "1=SOME" 2 "2=ALWAYS" ;
label define SI17      -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NEVER" 1 "1=SOME" 2 "2=ALWAYS" ;
label define SI18      -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NEVER" 1 "1=SOME" 2 "2=ALWAYS" ;
label define SI19      -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NEVER" 1 "1=SOME" 2 "2=ALWAYS" ;
label define SI20      -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NEVER" 1 "1=SOME" 2 "2=ALWAYS" ;
label define SI21      -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NEVER" 1 "1=SOME" 2 "2=ALWAYS" ;
label define SI22_1    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NEVER" 1 "1=SOME" 2 "2=ALWAYS" ;
label define SI22_2    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0 = $0" 10 "10 = $10" 12 "12 = $12" 15 "15 = $15"
                       20 "20 = $20" 25 "25 = $25" ;
label define SI23      -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI24      -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI25      -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI26      -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI27      -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI28      -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI29      -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI30      -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI31      -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI32      -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI32A     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI33      -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI34      -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI35      -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI36      -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI37      -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI38      -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI39      -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI40      -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI40A     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI40B     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI40C     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI40D     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI41      -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SI42      -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI43      -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI43A     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI43B     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI43C     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI43D     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI43E     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI43F     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI44      -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI45      -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI46      -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI47      -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI48      -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SI48_1    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SI48_2    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SI49      -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI49A     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SI49_1    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SI49_2    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SI50      -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI50A     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SI50A_1   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SI50A_2   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SI51_1    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI51_2    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0 = $0" 10 "10 = $10" 12 "12 = $12" 15 "15 = $15"
                       20 "20 = $20" 25 "25 = $25" ;
label define SI52_1    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI52_2    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0 = $0" 10 "10 = $10" 12 "12 = $12" 15 "15 = $15"
                       20 "20 = $20" 25 "25 = $25" ;
label define SI54      -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI55      -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI55A     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI55B     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI55C     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI55D     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI56      -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI57      -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI58      -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI59      -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI60      -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI61      -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI62      -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI62A     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI62B     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI62C     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI62D     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI63      -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SI64      -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI65      -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI65A     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SI66      -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI67      -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI68      -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SI68_1    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SI68_2    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SI69      -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI69A     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=A" 2 "2=B" 3 "3=OTHER" ;
label define SI70      -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI71      -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI72_1    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI72_2    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SI73      -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI74      -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI75      -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI76_1    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI76_2    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SI77      -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI78A     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI78B     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI78C     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI78A_1   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SI78A_2   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SI78A_3   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SI79      -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI80      -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI81      -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI82      -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI83      -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI84      -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI85_1    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI85_2    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0 = $0" 10 "10 = $10" 12 "12 = $12" 15 "15 = $15"
                       20 "20 = $20" 25 "25 = $25" ;
label define SI87      -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI88      -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI89      -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI90      -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI91      -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI92      -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI93      -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI94      -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI94A     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI94B     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI94C     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI94D     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI95      -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SI96      -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI97      -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI98      -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SI100     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI100A    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI100B    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI101     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI102     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI102B    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SI102C    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SI103     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI104     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI105     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI105A    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI105B    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI105C    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI106     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI107     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI108     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI109     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI109A    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0 = $0" 10 "10 = $10" 12 "12 = $12" 15 "15 = $15"
                       20 "20 = $20" 25 "25 = $25" ;
label define SI110     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI111     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI111A    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI112     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI113_1   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI113_2   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SI114_1   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI114_2   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SI115_1   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI115_2   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SI116     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI117     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI118     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI119     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI120     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI120A    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI120B    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI120C    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI120D    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI121     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SI122     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI123     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI124     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI125     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI126     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI127     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI128     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI129_1   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SI129_2   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SI129_3   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SI130     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=A" 2 "2=B" 3 "3=OTHER" ;
label define SI131     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=A" 2 "2=B" 3 "3=OTHER" ;
label define SI132     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI133     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI134_1   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SI134_2   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SI134_3   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SI135     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI136     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI137     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI137A    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=A" 2 "2=B" 3 "3=OTHER" ;
label define SI138     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI138A    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=A" 2 "2=B" 3 "3=OTHER" ;
label define SI139     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI139A    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=A" 2 "2=B" 3 "3=OTHER" ;
label define SI140     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" 2 "2=OPTIONAL" ;
label define SI141     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" 2 "2=OPTIONAL" ;
label define SI141A    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SI142     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI143     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI144     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" 2 "2=OPTIONAL" ;
label define SI145     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" 2 "2=OPTIONAL" ;
label define SI145A    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SI146     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI147A    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI147B    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI147C    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI147A_1  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SI147A_2  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SI147A_3  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SI148     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI149     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI150     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI151_1   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI151_2   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0 = $0" 10 "10 = $10" 12 "12 = $12" 15 "15 = $15"
                       20 "20 = $20" 25 "25 = $25" ;
label define SI153     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI154     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI155     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI156_1   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SI156_2   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SI156_3   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SI157     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI158     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI159     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI160     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI160A    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=A" 2 "2=B" 3 "3=OTHER" ;
label define SI161     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI161A    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=A" 2 "2=B" 3 "3=OTHER" ;
label define SI162     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI162A    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=A" 2 "2=B" 3 "3=OTHER" ;
label define SI163     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" 2 "2=OPTIONAL" ;
label define SI164     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" 2 "2=OPTIONAL" ;
label define SI164A    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SI165     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI166     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI167     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" 2 "2=OPTIONAL" ;
label define SI168     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" 2 "2=OPTIONAL" ;
label define SI168A    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SI169     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI170A    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI170B    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI170C    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI170A_1  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SI170A_2  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SI170A_3  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SI171     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI172     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI173     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI174_1   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI174_2   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0 = $0" 10 "10 = $10" 12 "12 = $12" 15 "15 = $15"
                       20 "20 = $20" 25 "25 = $25" ;
label define SI176     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI177     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI177A    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SI178     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI178A    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SI179     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI180     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI180A    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SI181     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI182     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI182A    -9.0 "-9 = SKIP, INELIG, NA" -8.0 "-8 = REFUSED"
                       -7.0 "-7 = DO NOT KNOW, UNSURE"
                       -6.0 "-6 = NOT APPLIC OR REFUSED"
                       -5.0 "-5 = SYSTEM MISSING" -4.0 "-4 = INVALID VALUE" ;
label define SI183     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI184     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI185     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI186     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI187     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI188     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI189     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SI190     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI191     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI192_1   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SI192_2   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SI192_3   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SI193     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI194     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI195     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI196     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI197     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI198     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI199     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI200_1   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI200A    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI201_1   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI202_1   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI203_1   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI204_1   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI205_1   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI206_1   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI208     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI209     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI210     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI211     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI212     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI213     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI215     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI216     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI217     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI217A_1  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SI217A_2  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SI217A_3  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SI217B    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SI218     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI218A    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI218B    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SI218C    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SI218D_1  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SI218D_2  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SI218D_3  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SESADUR   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SESBDUR   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SESAODUR  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SESBODUR  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define OUTDUR    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define DISTRIB1  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define DISTINJ   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define DISTSEX   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define REHNDLA   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define REHCNDMA  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define REHALLA   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define REHNDLB   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define REHCNDMB  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define REHALLB   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SIDEMOA   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SIDEMOB   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SIRHSLA   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SIRHSLB   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SIS1      -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SIS2A     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NOT CHECKED" 1 "1=CHECKED" ;
label define SIS2B     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NOT CHECKED" 1 "1=CHECKED" ;
label define SIS2C     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NOT CHECKED" 1 "1=CHECKED" ;
label define SIS2D     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NOT CHECKED" 1 "1=CHECKED" ;
label define SIS3      -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SIS4      -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SIS5      -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SIS6      -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SIS7      -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SIS8      -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NEVER" 1 "1=OCCASIONALLY/ON REQUEST"
                       2 "2=ROUTINELY" ;
label define SIS9      -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NEVER" 1 "1=OCCASIONALLY/ON REQUEST"
                       2 "2=ROUTINELY" ;
label define SIS9A     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NEVER" 1 "1=OCCASIONALLY/ON REQUEST"
                       2 "2=ROUTINELY" ;
label define SIS10     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NEVER" 1 "1=OCCASIONALLY/ON REQUEST"
                       2 "2=ROUTINELY" ;
label define SIS11     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NEVER" 1 "1=OCCASIONALLY/ON REQUEST"
                       2 "2=ROUTINELY" ;
label define SIS12     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SIS12A    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SIS13     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SIS14     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SIS15     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SIS16     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=YES, ALL CLIENTS" 2 "2=YES, WOMEN CLIENTS ONLY"
                       3 "3=NO" ;
label define SIS17     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=YES, ALL CLIENTS" 2 "2=YES, WOMEN CLIENTS ONLY"
                       3 "3=NO" ;
label define SIS17A    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SIS18     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=YES, ALL CLIENTS" 2 "2=YES, WOMEN CLIENTS ONLY"
                       3 "3=NO" ;
label define SIS19     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=YES, ALL CLIENTS" 2 "2=YES, WOMEN CLIENTS ONLY"
                       3 "3=NO" ;
label define SIS20     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SIS21     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SIS22     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SIS23     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SIS24     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SIS25     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SIS26     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SIS27     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SIS28     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NEVER" 1 "1=OCCASIONALLY/ON REQUEST"
                       2 "2=ROUTINELY" ;
label define SIS29     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NEVER" 1 "1=OCCASIONALLY/ON REQUEST"
                       2 "2=ROUTINELY" ;
label define SIS30     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NEVER" 1 "1=OCCASIONALLY/ON REQUEST"
                       2 "2=ROUTINELY" ;
label define SIS31     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NEVER" 1 "1=OCCASIONALLY/ON REQUEST"
                       2 "2=ROUTINELY" ;
label define SIS32     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NEVER" 1 "1=OCCASIONALLY/ON REQUEST"
                       2 "2=ROUTINELY" ;
label define SIS33     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NEVER" 1 "1=OCCASIONALLY/ON REQUEST"
                       2 "2=ROUTINELY" ;
label define SIS34     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NEVER" 1 "1=OCCASIONALLY/ON REQUEST"
                       2 "2=ROUTINELY" ;
label define SIS35     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NEVER" 1 "1=OCCASIONALLY/ON REQUEST"
                       2 "2=ROUTINELY" ;
label define SIS36A    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SIS36B    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SIS36C    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SIS37A    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SIS37B    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SIS37C    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SIS38     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SIS39     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SIS40     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SIS41     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SIS42     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=YES, ALL CLIENTS" 2 "2=YES, WOMEN CLIENTS ONLY"
                       3 "3=NO" ;
label define SIS43     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=YES, ALL CLIENTS" 2 "2=YES, WOMEN CLIENTS ONLY"
                       3 "3=NO" ;
label define SIS43A    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SIS44     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=YES, ALL CLIENTS" 2 "2=YES, WOMEN CLIENTS ONLY"
                       3 "3=NO" ;
label define SIS45     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=YES, ALL CLIENTS" 2 "2=YES, WOMEN CLIENTS ONLY"
                       3 "3=NO" ;
label define SIS46     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SIS47     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SIS48     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SIS49     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SIS50     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SIS51     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SIS52     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SIS53     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SIS54     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NEVER" 1 "1=OCCASIONALLY/ON REQUEST"
                       2 "2=ROUTINELY" ;
label define SIS55     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NEVER" 1 "1=OCCASIONALLY/ON REQUEST"
                       2 "2=ROUTINELY" ;
label define SIS56     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NEVER" 1 "1=OCCASIONALLY/ON REQUEST"
                       2 "2=ROUTINELY" ;
label define SIS57     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NEVER" 1 "1=OCCASIONALLY/ON REQUEST"
                       2 "2=ROUTINELY" ;
label define SIS58     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NEVER" 1 "1=OCCASIONALLY/ON REQUEST"
                       2 "2=ROUTINELY" ;
label define SIS59     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NEVER" 1 "1=OCCASIONALLY/ON REQUEST"
                       2 "2=ROUTINELY" ;
label define SIS60     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NEVER" 1 "1=OCCASIONALLY/ON REQUEST"
                       2 "2=ROUTINELY" ;
label define SIS61     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NEVER" 1 "1=OCCASIONALLY/ON REQUEST"
                       2 "2=ROUTINELY" ;
label define SIS62A    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SIS62B    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SIS62C    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SIS63A    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SIS63B    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SIS63C    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SIS64     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SIS65     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SIS66     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SIS67     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SIS68     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=YES, ALL CLIENTS" 2 "2=YES, WOMEN CLIENTS ONLY"
                       3 "3=NO" ;
label define SIS69     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=YES, ALL CLIENTS" 2 "2=YES, WOMEN CLIENTS ONLY"
                       3 "3=NO" ;
label define SIS69A    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SIS70     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=YES, ALL CLIENTS" 2 "2=YES, WOMEN CLIENTS ONLY"
                       3 "3=NO" ;
label define SIS71     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=YES, ALL CLIENTS" 2 "2=YES, WOMEN CLIENTS ONLY"
                       3 "3=NO" ;
label define SIS72     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SIS73     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SIS74     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SIS75     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SIS76     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SIS77     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SIS78     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SIS79     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SIS80     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NEVER" 1 "1=OCCASIONALLY/ON REQUEST"
                       2 "2=ROUTINELY" ;
label define SIS81     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NEVER" 1 "1=OCCASIONALLY/ON REQUEST"
                       2 "2=ROUTINELY" ;
label define SIS82     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NEVER" 1 "1=OCCASIONALLY/ON REQUEST"
                       2 "2=ROUTINELY" ;
label define SIS83     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NEVER" 1 "1=OCCASIONALLY/ON REQUEST"
                       2 "2=ROUTINELY" ;
label define SIS84     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NEVER" 1 "1=OCCASIONALLY/ON REQUEST"
                       2 "2=ROUTINELY" ;
label define SIS85     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NEVER" 1 "1=OCCASIONALLY/ON REQUEST"
                       2 "2=ROUTINELY" ;
label define SIS86     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NEVER" 1 "1=OCCASIONALLY/ON REQUEST"
                       2 "2=ROUTINELY" ;
label define SIS87     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NEVER" 1 "1=OCCASIONALLY/ON REQUEST"
                       2 "2=ROUTINELY" ;
label define SIS88A    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SIS88B    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SIS88C    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SIS89A    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SIS89B    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SIS89C    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define SIS90     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SIS91     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SIS92     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SIS93     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SIS94     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SIS95     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NEVER" 1 "1=OCCASIONALLY/ON REQUEST"
                       2 "2=ROUTINELY" ;
label define SIS96     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NEVER" 1 "1=OCCASIONALLY/ON REQUEST"
                       2 "2=ROUTINELY" ;
label define SIS97     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NEVER" 1 "1=OCCASIONALLY/ON REQUEST"
                       2 "2=ROUTINELY" ;
label define SIS98     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NEVER" 1 "1=OCCASIONALLY/ON REQUEST"
                       2 "2=ROUTINELY" ;
label define SIS99     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NEVER" 1 "1=OCCASIONALLY/ON REQUEST"
                       2 "2=ROUTINELY" ;
label define SIS100    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NEVER" 1 "1=OCCASIONALLY/ON REQUEST"
                       2 "2=ROUTINELY" ;
label define SIS101    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NEVER" 1 "1=OCCASIONALLY/ON REQUEST"
                       2 "2=ROUTINELY" ;
label define SIS102    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NEVER" 1 "1=OCCASIONALLY/ON REQUEST"
                       2 "2=ROUTINELY" ;
label define SIS103A   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SIS103B   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SIS103C   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SIS106    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SIS107    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SIS108    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SIS109    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NEVER" 1 "1=OCCASIONALLY/ON REQUEST"
                       2 "2=ROUTINELY" ;
label define SIS110    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NEVER" 1 "1=OCCASIONALLY/ON REQUEST"
                       2 "2=ROUTINELY" ;
label define SIS111    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NEVER" 1 "1=OCCASIONALLY/ON REQUEST"
                       2 "2=ROUTINELY" ;
label define SIS112    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NEVER" 1 "1=OCCASIONALLY/ON REQUEST"
                       2 "2=ROUTINELY" ;
label define SIS113    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NEVER" 1 "1=OCCASIONALLY/ON REQUEST"
                       2 "2=ROUTINELY" ;
label define SIS114    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NEVER" 1 "1=OCCASIONALLY/ON REQUEST"
                       2 "2=ROUTINELY" ;
label define SIS115    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NEVER" 1 "1=OCCASIONALLY/ON REQUEST"
                       2 "2=ROUTINELY" ;
label define SIS116    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NEVER" 1 "1=OCCASIONALLY/ON REQUEST"
                       2 "2=ROUTINELY" ;
label define SIS117A   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SIS117B   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SIS117C   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SIS120    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SIS121    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SIS122    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SIS123    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NEVER" 1 "1=OCCASIONALLY/ON REQUEST"
                       2 "2=ROUTINELY" ;
label define SIS124    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NEVER" 1 "1=OCCASIONALLY/ON REQUEST"
                       2 "2=ROUTINELY" ;
label define SIS125    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NEVER" 1 "1=OCCASIONALLY/ON REQUEST"
                       2 "2=ROUTINELY" ;
label define SIS126    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NEVER" 1 "1=OCCASIONALLY/ON REQUEST"
                       2 "2=ROUTINELY" ;
label define SIS127    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NEVER" 1 "1=OCCASIONALLY/ON REQUEST"
                       2 "2=ROUTINELY" ;
label define SIS128    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NEVER" 1 "1=OCCASIONALLY/ON REQUEST"
                       2 "2=ROUTINELY" ;
label define SIS129    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NEVER" 1 "1=OCCASIONALLY/ON REQUEST"
                       2 "2=ROUTINELY" ;
label define SIS130    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NEVER" 1 "1=OCCASIONALLY/ON REQUEST"
                       2 "2=ROUTINELY" ;
label define SIS131A   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SIS131B   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SIS131C   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define SIS134    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY SMALL" 2 "2=SMALL" 3 "3=MODERATE"
                       4 "4=LARGE" 5 "5=VERY LARGE" ;
label define SIS135    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY SMALL" 2 "2=SMALL" 3 "3=MODERATE"
                       4 "4=LARGE" 5 "5=VERY LARGE" ;
label define SIS136    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY SMALL" 2 "2=SMALL" 3 "3=MODERATE"
                       4 "4=LARGE" 5 "5=VERY LARGE" ;
label define SIS137    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY SMALL" 2 "2=SMALL" 3 "3=MODERATE"
                       4 "4=LARGE" 5 "5=VERY LARGE" ;
label define SIS138    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY SMALL" 2 "2=SMALL" 3 "3=MODERATE"
                       4 "4=LARGE" 5 "5=VERY LARGE" ;
label define SIS139    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY SMALL" 2 "2=SMALL" 3 "3=MODERATE"
                       4 "4=LARGE" 5 "5=VERY LARGE" ;
label define SIS140    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY SMALL" 2 "2=SMALL" 3 "3=MODERATE"
                       4 "4=LARGE" 5 "5=VERY LARGE" ;
label define SIS141    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY SMALL" 2 "2=SMALL" 3 "3=MODERATE"
                       4 "4=LARGE" 5 "5=VERY LARGE" ;
label define SIS142    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY SMALL" 2 "2=SMALL" 3 "3=MODERATE"
                       4 "4=LARGE" 5 "5=VERY LARGE" ;
label define EINUM     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define EI1       -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define EI2_1     -9.00 "-9 = SKIP, INELIG, NA" -8.00 "-8 = REFUSED"
                       -7.00 "-7 = DO NOT KNOW, UNSURE"
                       -6.00 "-6 = NOT APPLIC OR REFUSED"
                       -5.00 "-5 = SYSTEM MISSING" -4.00 "-4 = INVALID VALUE" ;
label define EI2_2     -9.0 "-9 = SKIP, INELIG, NA" -8.0 "-8 = REFUSED"
                       -7.0 "-7 = DO NOT KNOW, UNSURE"
                       -6.0 "-6 = NOT APPLIC OR REFUSED"
                       -5.0 "-5 = SYSTEM MISSING" -4.0 "-4 = INVALID VALUE" ;
label define EI2_3     -9.00 "-9 = SKIP, INELIG, NA" -8.00 "-8 = REFUSED"
                       -7.00 "-7 = DO NOT KNOW, UNSURE"
                       -6.00 "-6 = NOT APPLIC OR REFUSED"
                       -5.00 "-5 = SYSTEM MISSING" -4.00 "-4 = INVALID VALUE" ;
label define EI2_4     -9.00 "-9 = SKIP, INELIG, NA" -8.00 "-8 = REFUSED"
                       -7.00 "-7 = DO NOT KNOW, UNSURE"
                       -6.00 "-6 = NOT APPLIC OR REFUSED"
                       -5.00 "-5 = SYSTEM MISSING" -4.00 "-4 = INVALID VALUE" ;
label define EI2_5     -9.00 "-9 = SKIP, INELIG, NA" -8.00 "-8 = REFUSED"
                       -7.00 "-7 = DO NOT KNOW, UNSURE"
                       -6.00 "-6 = NOT APPLIC OR REFUSED"
                       -5.00 "-5 = SYSTEM MISSING" -4.00 "-4 = INVALID VALUE" ;
label define EI2_6     -9.00 "-9 = SKIP, INELIG, NA" -8.00 "-8 = REFUSED"
                       -7.00 "-7 = DO NOT KNOW, UNSURE"
                       -6.00 "-6 = NOT APPLIC OR REFUSED"
                       -5.00 "-5 = SYSTEM MISSING" -4.00 "-4 = INVALID VALUE" ;
label define EI3A_1    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define EI3A_2    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define EI3A_3    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define EI3A_4    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define EI3B      -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=STRUCTURE" 2 "2=SEMI-STRUCTURE" 3 "3=FLEXIBLE" ;
label define EI4A_1    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define EI4A_2    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define EI4B_3    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define EI4B_4    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define EI4B_5    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define EI4B_6    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define EI5_1     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define EI5_2     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define EI6       -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=AT THE SAME TIME" 2 "2=8-14 DAYS AFTER"
                       3 "3=15 OR MORE DAYS" ;
label define EI7A_1    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NOT IMPORTANT" 1 "1=SLIGHTLY IMPORTANT"
                       2 "2=SOMEWHAT IMPORTANT" 3 "3=VERY IMPORTANT" ;
label define EI7A_2    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NOT IMPORTANT" 1 "1=SLIGHTLY IMPORTANT"
                       2 "2=SOMEWHAT IMPORTANT" 3 "3=VERY IMPORTANT" ;
label define EI7A_3    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NOT IMPORTANT" 1 "1=SLIGHTLY IMPORTANT"
                       2 "2=SOMEWHAT IMPORTANT" 3 "3=VERY IMPORTANT" ;
label define EI7A_4    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NOT IMPORTANT" 1 "1=SLIGHTLY IMPORTANT"
                       2 "2=SOMEWHAT IMPORTANT" 3 "3=VERY IMPORTANT" ;
label define EI7A_5    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NOT IMPORTANT" 1 "1=SLIGHTLY IMPORTANT"
                       2 "2=SOMEWHAT IMPORTANT" 3 "3=VERY IMPORTANT" ;
label define EI7A_6    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NOT IMPORTANT" 1 "1=SLIGHTLY IMPORTANT"
                       2 "2=SOMEWHAT IMPORTANT" 3 "3=VERY IMPORTANT" ;
label define EI7A_7    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NOT IMPORTANT" 1 "1=SLIGHTLY IMPORTANT"
                       2 "2=SOMEWHAT IMPORTANT" 3 "3=VERY IMPORTANT" ;
label define EI7A_8    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NOT IMPORTANT" 1 "1=SLIGHTLY IMPORTANT"
                       2 "2=SOMEWHAT IMPORTANT" 3 "3=VERY IMPORTANT" ;
label define EI7A_9    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NOT IMPORTANT" 1 "1=SLIGHTLY IMPORTANT"
                       2 "2=SOMEWHAT IMPORTANT" 3 "3=VERY IMPORTANT" ;
label define EI7A_10   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NOT IMPORTANT" 1 "1=SLIGHTLY IMPORTANT"
                       2 "2=SOMEWHAT IMPORTANT" 3 "3=VERY IMPORTANT" ;
label define EI7A_11   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NOT IMPORTANT" 1 "1=SLIGHTLY IMPORTANT"
                       2 "2=SOMEWHAT IMPORTANT" 3 "3=VERY IMPORTANT" ;
label define EI7A_12   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NOT IMPORTANT" 1 "1=SLIGHTLY IMPORTANT"
                       2 "2=SOMEWHAT IMPORTANT" 3 "3=VERY IMPORTANT" ;
label define EI7B_1    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NOT IMPORTANT" 1 "1=SLIGHTLY IMPORTANT"
                       2 "2=SOMEWHAT IMPORTANT" 3 "3=VERY IMPORTANT" ;
label define EI7B_2    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NOT IMPORTANT" 1 "1=SLIGHTLY IMPORTANT"
                       2 "2=SOMEWHAT IMPORTANT" 3 "3=VERY IMPORTANT" ;
label define EI7B_3    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NOT IMPORTANT" 1 "1=SLIGHTLY IMPORTANT"
                       2 "2=SOMEWHAT IMPORTANT" 3 "3=VERY IMPORTANT" ;
label define EI7B_4    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NOT IMPORTANT" 1 "1=SLIGHTLY IMPORTANT"
                       2 "2=SOMEWHAT IMPORTANT" 3 "3=VERY IMPORTANT" ;
label define EI7B_5    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NOT IMPORTANT" 1 "1=SLIGHTLY IMPORTANT"
                       2 "2=SOMEWHAT IMPORTANT" 3 "3=VERY IMPORTANT" ;
label define EI7B_6    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NOT IMPORTANT" 1 "1=SLIGHTLY IMPORTANT"
                       2 "2=SOMEWHAT IMPORTANT" 3 "3=VERY IMPORTANT" ;
label define EI7B_7    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NOT IMPORTANT" 1 "1=SLIGHTLY IMPORTANT"
                       2 "2=SOMEWHAT IMPORTANT" 3 "3=VERY IMPORTANT" ;
label define EI7B_8    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NOT IMPORTANT" 1 "1=SLIGHTLY IMPORTANT"
                       2 "2=SOMEWHAT IMPORTANT" 3 "3=VERY IMPORTANT" ;
label define EI7B_9    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NOT IMPORTANT" 1 "1=SLIGHTLY IMPORTANT"
                       2 "2=SOMEWHAT IMPORTANT" 3 "3=VERY IMPORTANT" ;
label define EI7B_10   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NOT IMPORTANT" 1 "1=SLIGHTLY IMPORTANT"
                       2 "2=SOMEWHAT IMPORTANT" 3 "3=VERY IMPORTANT" ;
label define EI8A_1    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NOT IMPORTANT" 1 "1=SLIGHTLY IMPORTANT"
                       2 "2=SOMEWHAT IMPORTANT" 3 "3=VERY IMPORTANT" ;
label define EI8A_2    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NOT IMPORTANT" 1 "1=SLIGHTLY IMPORTANT"
                       2 "2=SOMEWHAT IMPORTANT" 3 "3=VERY IMPORTANT" ;
label define EI8A_3    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NOT IMPORTANT" 1 "1=SLIGHTLY IMPORTANT"
                       2 "2=SOMEWHAT IMPORTANT" 3 "3=VERY IMPORTANT" ;
label define EI8A_4    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NOT IMPORTANT" 1 "1=SLIGHTLY IMPORTANT"
                       2 "2=SOMEWHAT IMPORTANT" 3 "3=VERY IMPORTANT" ;
label define EI8A_5    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NOT IMPORTANT" 1 "1=SLIGHTLY IMPORTANT"
                       2 "2=SOMEWHAT IMPORTANT" 3 "3=VERY IMPORTANT" ;
label define EI8A_6    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NOT IMPORTANT" 1 "1=SLIGHTLY IMPORTANT"
                       2 "2=SOMEWHAT IMPORTANT" 3 "3=VERY IMPORTANT" ;
label define EI8A_7    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NOT IMPORTANT" 1 "1=SLIGHTLY IMPORTANT"
                       2 "2=SOMEWHAT IMPORTANT" 3 "3=VERY IMPORTANT" ;
label define EI8A_8    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NOT IMPORTANT" 1 "1=SLIGHTLY IMPORTANT"
                       2 "2=SOMEWHAT IMPORTANT" 3 "3=VERY IMPORTANT" ;
label define EI8A_9    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NOT IMPORTANT" 1 "1=SLIGHTLY IMPORTANT"
                       2 "2=SOMEWHAT IMPORTANT" 3 "3=VERY IMPORTANT" ;
label define EI8A_10   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NOT IMPORTANT" 1 "1=SLIGHTLY IMPORTANT"
                       2 "2=SOMEWHAT IMPORTANT" 3 "3=VERY IMPORTANT" ;
label define EI8A_11   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NOT IMPORTANT" 1 "1=SLIGHTLY IMPORTANT"
                       2 "2=SOMEWHAT IMPORTANT" 3 "3=VERY IMPORTANT" ;
label define EI8A_12   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NOT IMPORTANT" 1 "1=SLIGHTLY IMPORTANT"
                       2 "2=SOMEWHAT IMPORTANT" 3 "3=VERY IMPORTANT" ;
label define EI8A_13   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NOT IMPORTANT" 1 "1=SLIGHTLY IMPORTANT"
                       2 "2=SOMEWHAT IMPORTANT" 3 "3=VERY IMPORTANT" ;
label define EI8A_14   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NOT IMPORTANT" 1 "1=SLIGHTLY IMPORTANT"
                       2 "2=SOMEWHAT IMPORTANT" 3 "3=VERY IMPORTANT" ;
label define EI8B_1    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NOT IMPORTANT" 1 "1=SLIGHTLY IMPORTANT"
                       2 "2=SOMEWHAT IMPORTANT" 3 "3=VERY IMPORTANT" ;
label define EI8B_2    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NOT IMPORTANT" 1 "1=SLIGHTLY IMPORTANT"
                       2 "2=SOMEWHAT IMPORTANT" 3 "3=VERY IMPORTANT" ;
label define EI8B_3    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NOT IMPORTANT" 1 "1=SLIGHTLY IMPORTANT"
                       2 "2=SOMEWHAT IMPORTANT" 3 "3=VERY IMPORTANT" ;
label define EI8B_4    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NOT IMPORTANT" 1 "1=SLIGHTLY IMPORTANT"
                       2 "2=SOMEWHAT IMPORTANT" 3 "3=VERY IMPORTANT" ;
label define EI9       -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define EI10      -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NONE" 1 "1=SOME" 2 "2=ALL" ;
label define EI11_1    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NOT IMPORTANT" 1 "1=SLIGHTLY IMPORTANT"
                       2 "2=SOMEWHAT IMPORTANT" 3 "3=VERY IMPORTANT" ;
label define EI11_2    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NOT IMPORTANT" 1 "1=SLIGHTLY IMPORTANT"
                       2 "2=SOMEWHAT IMPORTANT" 3 "3=VERY IMPORTANT" ;
label define EI11_3    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NOT IMPORTANT" 1 "1=SLIGHTLY IMPORTANT"
                       2 "2=SOMEWHAT IMPORTANT" 3 "3=VERY IMPORTANT" ;
label define EI11_4    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NOT IMPORTANT" 1 "1=SLIGHTLY IMPORTANT"
                       2 "2=SOMEWHAT IMPORTANT" 3 "3=VERY IMPORTANT" ;
label define EI11_5    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NOT IMPORTANT" 1 "1=SLIGHTLY IMPORTANT"
                       2 "2=SOMEWHAT IMPORTANT" 3 "3=VERY IMPORTANT" ;
label define EI11_6    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NOT IMPORTANT" 1 "1=SLIGHTLY IMPORTANT"
                       2 "2=SOMEWHAT IMPORTANT" 3 "3=VERY IMPORTANT" ;
label define EI11_7    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NOT IMPORTANT" 1 "1=SLIGHTLY IMPORTANT"
                       2 "2=SOMEWHAT IMPORTANT" 3 "3=VERY IMPORTANT" ;
label define EI11_8    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NOT IMPORTANT" 1 "1=SLIGHTLY IMPORTANT"
                       2 "2=SOMEWHAT IMPORTANT" 3 "3=VERY IMPORTANT" ;
label define EI11_9    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NOT IMPORTANT" 1 "1=SLIGHTLY IMPORTANT"
                       2 "2=SOMEWHAT IMPORTANT" 3 "3=VERY IMPORTANT" ;
label define EI11_10   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NOT IMPORTANT" 1 "1=SLIGHTLY IMPORTANT"
                       2 "2=SOMEWHAT IMPORTANT" 3 "3=VERY IMPORTANT" ;
label define EI11_11   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NOT IMPORTANT" 1 "1=SLIGHTLY IMPORTANT"
                       2 "2=SOMEWHAT IMPORTANT" 3 "3=VERY IMPORTANT" ;
label define EI11_12   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NOT IMPORTANT" 1 "1=SLIGHTLY IMPORTANT"
                       2 "2=SOMEWHAT IMPORTANT" 3 "3=VERY IMPORTANT" ;
label define EI11_13   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NOT IMPORTANT" 1 "1=SLIGHTLY IMPORTANT"
                       2 "2=SOMEWHAT IMPORTANT" 3 "3=VERY IMPORTANT" ;
label define EI11_14   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NOT IMPORTANT" 1 "1=SLIGHTLY IMPORTANT"
                       2 "2=SOMEWHAT IMPORTANT" 3 "3=VERY IMPORTANT" ;
label define EI11_15   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NOT IMPORTANT" 1 "1=SLIGHTLY IMPORTANT"
                       2 "2=SOMEWHAT IMPORTANT" 3 "3=VERY IMPORTANT" ;
label define EI12_2    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define EI14_1    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NOT CHECKED" 1 "1=CHECKED" ;
label define EI14_2    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NOT CHECKED" 1 "1=CHECKED" ;
label define EI14_3    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NOT CHECKED" 1 "1=CHECKED" ;
label define EI14_4    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NOT CHECKED" 1 "1=CHECKED" ;
label define EI14_5    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NOT CHECKED" 1 "1=CHECKED" ;
label define EIDEMO    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define EIRHSL    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define EIACTA    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define EIACTB    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define EIDISTA   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define EIDISTB   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define EIDUR     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define EIADUR    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define EIBDUR    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define EIAODUR   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define EIBODUR   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define EIIND     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0 = NO" 1 "1 = YES" ;
label define EICOUPLE  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0 = NO" 1 "1 = YES" ;
label define EIGROUP   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0 = NO" 1 "1 = YES" ;
label define XDAMC     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define AINTCOU   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define AINTEDU   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define AINTBOTH  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define AINTOTH   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define AINTSP    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=INTERACTIVE APPROACH"
                       2 "2=FACILITATION/REFERRALS" 3 "3=NEITHER" ;
label define AINTAV    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define AAVVIDEO  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define AAVHAND   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define AAVOTHER  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define AAVSP     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=PHOTOS DEMO NEEDLE CLNG"
                       2 "2=CULTURAL APPROP. VISUAL AIDS"
                       3 "3=CASE STUDY STORIES," 4 "4=DRY ERASE BOARD"
                       5 "5=CLIENTS DRAWINGS AND WORKSHEETS"
                       6 "6=PHOTO SLIDES" 7 "7=KNOWLEDGE TESTING" ;
label define AINTDRUG  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define AINTSEX   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define ABARRIER  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define ASUPPORT  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define ACUES     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define ASETGOAL  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define AINTPER   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define ATB       -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NOT VERY" 1 "1=SOMEWHAT" 2 "2=VERY" ;
label define AANATOMY  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NOT VERY" 1 "1=SOMEWHAT" 2 "2=VERY" ;
label define AAPCLIEN  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NOT VERY" 1 "1=SOMEWHAT" 2 "2=VERY" ;
label define ASELFHLP  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NOT VERY" 1 "1=SOMEWHAT" 2 "2=VERY" ;
label define ACOMMIT   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NOT VERY" 1 "1=SOMEWHAT" 2 "2=VERY" ;
label define ACOMPRTN  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NOT VERY" 1 "1=SOMEWHAT" 2 "2=VERY" ;
label define ACOMPMED  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NOT VERY" 1 "1=SOMEWHAT" 2 "2=VERY" ;
label define ALIFPAIN  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NOT VERY" 1 "1=SOMEWHAT" 2 "2=VERY" ;
label define ABLDTRST  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NOT VERY" 1 "1=SOMEWHAT" 2 "2=VERY" ;
label define ADISCRIM  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NOT VERY" 1 "1=SOMEWHAT" 2 "2=VERY" ;
label define ADOMVIOL  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NOT VERY" 1 "1=SOMEWHAT" 2 "2=VERY" ;
label define AFACACC   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NOT VERY" 1 "1=SOMEWHAT" 2 "2=VERY" ;
label define AFAMISS   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NOT VERY" 1 "1=SOMEWHAT" 2 "2=VERY" ;
label define AFOODPRP  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NOT VERY" 1 "1=SOMEWHAT" 2 "2=VERY" ;
label define AHLTHTX   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NOT VERY" 1 "1=SOMEWHAT" 2 "2=VERY" ;
label define AHLTHTOP  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NOT VERY" 1 "1=SOMEWHAT" 2 "2=VERY" ;
label define AHOMELES  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NOT VERY" 1 "1=SOMEWHAT" 2 "2=VERY" ;
label define APOSAT    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NOT VERY" 1 "1=SOMEWHAT" 2 "2=VERY" ;
label define ALIFPATT  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NOT VERY" 1 "1=SOMEWHAT" 2 "2=VERY" ;
label define AMORDEMO  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NOT VERY" 1 "1=SOMEWHAT" 2 "2=VERY" ;
label define ANEGSKIL  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NOT VERY" 1 "1=SOMEWHAT" 2 "2=VERY" ;
label define APEERSUP  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NOT VERY" 1 "1=SOMEWHAT" 2 "2=VERY" ;
label define AROLES    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NOT VERY" 1 "1=SOMEWHAT" 2 "2=VERY" ;
label define AREDUBEH  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NOT VERY" 1 "1=SOMEWHAT" 2 "2=VERY" ;
label define APOVERTY  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NOT VERY" 1 "1=SOMEWHAT" 2 "2=VERY" ;
label define APWRLES   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NOT VERY" 1 "1=SOMEWHAT" 2 "2=VERY" ;
label define APROMSLF  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NOT VERY" 1 "1=SOMEWHAT" 2 "2=VERY" ;
label define ATBTST    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NOT VERY" 1 "1=SOMEWHAT" 2 "2=VERY" ;
label define ADISCST   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NOT VERY" 1 "1=SOMEWHAT" 2 "2=VERY" ;
label define ARESPECT  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NOT VERY" 1 "1=SOMEWHAT" 2 "2=VERY" ;
label define AROLPLAY  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NOT VERY" 1 "1=SOMEWHAT" 2 "2=VERY" ;
label define ASLFEFF   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NOT VERY" 1 "1=SOMEWHAT" 2 "2=VERY" ;
label define ASLFENH   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NOT VERY" 1 "1=SOMEWHAT" 2 "2=VERY" ;
label define ASLFEST   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NOT VERY" 1 "1=SOMEWHAT" 2 "2=VERY" ;
label define ASKLLTRA  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NOT VERY" 1 "1=SOMEWHAT" 2 "2=VERY" ;
label define ASTRMAN   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NOT VERY" 1 "1=SOMEWHAT" 2 "2=VERY" ;
label define ASOCIALS  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NOT VERY" 1 "1=SOMEWHAT" 2 "2=VERY" ;
label define APHOTDEM  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NOT VERY" 1 "1=SOMEWHAT" 2 "2=VERY" ;
label define ATALID    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NOT VERY" 1 "1=SOMEWHAT" 2 "2=VERY" ;
label define ATRUST    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NOT VERY" 1 "1=SOMEWHAT" 2 "2=VERY" ;
label define AETHCUL   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NOT VERY" 1 "1=SOMEWHAT" 2 "2=VERY" ;
label define AWLLBNG   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NOT VERY" 1 "1=SOMEWHAT" 2 "2=VERY" ;
label define AOTH      -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NOT VERY" 1 "1=SOMEWHAT" 2 "2=VERY" ;
label define AHIV      -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define AOTHISS   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define ABOTH     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define AHIVFRST  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define AISSFRST  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define AIND      -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define AGRP      -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define AGRPSZ    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=1-2 HLTH ED & 2-7 CLIENTS" 1 "1=2-3" 2 "2=3-9"
                       3 "3=2-20" 4 "4=2-8" 5 "5=2 OR MORE" 6 "6=3-6"
                       7 "7=10-12" 8 "8=VARIABLE" ;
label define AGRPCOMP  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO ANSWER" 1 "1=SEX PRTNR, FRIENDS, FAMILY"
                       2 "2=INTERVENTION CHARTS" 3 "3=DRUG NETWORKS & PART"
                       4 "4=ETHNIC TARGET LATINS/AFR AMER"
                       5 "5=PERSONAL NETWORK" 6 "6=AFRICAN AMER MALE IV"
                       7 "7=MIXED BOTH GENDERS" 8 "8=WOMENS, MENS GROUP"
                       10 "10=HEALTH EDUCATORS & CLIENTS" ;
label define AOTH_     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define AOTH_SP   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=COUPLES UPON REQUEST" 2 "2=COMMUNITY BASED"
                       3 "3=THOSE VISITS W/FAMILY"
                       4 "4=INDIVIDUAL GROUP AND OTHER" 5 "5=MONTHLY SOCIALS" ;
label define APROJOFF  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define ASTREET   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define AVAN      -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define AOTHPLAC  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define AOTHSPPL  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VEHICLES, HOMES AND RESTURANTS"
                       2 "2=HOMES/BARS/CARS/CRACK HOUSES"
                       3 "3=PROJECT OFFICE/VAN/STREET/COMMUNITY CN"
                       4 "4=ACCOMPANY CLNT TO DRUG TX/SELF-HLP GRP"
                       5 "5=CLIENTS HOMES" ;
label define APREF_    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define ASES1     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=0" 1 "1=15-20 MINS" 2 "2=55 MINS"
                       3 "3=30-60 MINS FIELD" 4 "4=15-60 MINS" 5 "5=60 MINS"
                       6 "6=45-60 MINS" 7 "7=90 MINS" 8 "8=50 MINS"
                       9 "9=45 MINUTES INDIVIDUAL" 10 "10=60-90 MINS"
                       11 "11=15 MINS" 12 "12=VARIES" 13 "13=20 MINS"
                       14 "14=60 MINUTES GROUP" 15 "15=3 HRS SOCIALS"
                       16 "16=30 MINUTES FUP" 17 "17=45 MINS" ;
label define ASES2     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=0" 1 "1=15-20 MINS" 2 "2=55 MINS"
                       3 "3=30-60 MINS FIELD" 4 "4=15-60 MINS" 5 "5=60 MINS"
                       6 "6=45-60 MINS" 7 "7=90 MINS" 8 "8=50 MINS"
                       9 "9=45 MINUTES INDIVIDUAL" 10 "10=60-90 MINS"
                       11 "11=15 MINS" 12 "12=VARIES" 13 "13=20 MINS"
                       14 "14=60 MINUTES GROUP" 15 "15=3 HRS SOCIALS"
                       16 "16=30 MINUTES FUP" 17 "17=45 MINS" ;
label define ASES3     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=0" 1 "1=15-20 MINS" 2 "2=55 MINS"
                       3 "3=30-60 MINS FIELD" 4 "4=15-60 MINS" 5 "5=60 MINS"
                       6 "6=45-60 MINS" 7 "7=90 MINS" 8 "8=50 MINS"
                       9 "9=45 MINUTES INDIVIDUAL" 10 "10=60-90 MINS"
                       11 "11=15 MINS" 12 "12=VARIES" 13 "13=20 MINS"
                       14 "14=60 MINUTES GROUP" 15 "15=3 HRS SOCIALS"
                       16 "16=30 MINUTES FUP" 17 "17=45 MINS" ;
label define ASES4     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=0" 1 "1=15-20 MINS" 2 "2=55 MINS"
                       3 "3=30-60 MINS FIELD" 4 "4=15-60 MINS" 5 "5=60 MINS"
                       6 "6=45-60 MINS" 7 "7=90 MINS" 8 "8=50 MINS"
                       9 "9=45 MINUTES INDIVIDUAL" 10 "10=60-90 MINS"
                       11 "11=15 MINS" 12 "12=VARIES" 13 "13=20 MINS"
                       14 "14=60 MINUTES GROUP" 15 "15=3 HRS SOCIALS"
                       16 "16=30 MINUTES FUP" 17 "17=45 MINS" ;
label define ASES5     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=0" 1 "1=15-20 MINS" 2 "2=55 MINS"
                       3 "3=30-60 MINS FIELD" 4 "4=15-60 MINS" 5 "5=60 MINS"
                       6 "6=45-60 MINS" 7 "7=90 MINS" 8 "8=50 MINS"
                       9 "9=45 MINUTES INDIVIDUAL" 10 "10=60-90 MINS"
                       11 "11=15 MINS" 12 "12=VARIES" 13 "13=20 MINS"
                       14 "14=60 MINUTES GROUP" 15 "15=3 HRS SOCIALS"
                       16 "16=30 MINUTES FUP" 17 "17=45 MINS" ;
label define ASES6     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=0" 1 "1=15-20 MINS" 2 "2=55 MINS"
                       3 "3=30-60 MINS FIELD" 4 "4=15-60 MINS" 5 "5=60 MINS"
                       6 "6=45-60 MINS" 7 "7=90 MINS" 8 "8=50 MINS"
                       9 "9=45 MINUTES INDIVIDUAL" 10 "10=60-90 MINS"
                       11 "11=15 MINS" 12 "12=VARIES" 13 "13=20 MINS"
                       14 "14=60 MINUTES GROUP" 15 "15=3 HRS SOCIALS"
                       16 "16=30 MINUTES FUP" 17 "17=45 MINS" ;
label define ANONE     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define APHONE    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define APHONE_   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=IF MISS APPOINTMENT" 2 "2=1 FOLUP" 3 "3=5 CALLS"
                       4 "4=AS NEEDED UP TO 1 MONTH" ;
label define AOUTWOR   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define AOUTWOR_  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO ANSWER" 1 "1=3-4 CALLS"
                       2 "2=IF MISS APPOINTMENT" 3 "3=4 CALLS"
                       4 "4=AS NEEDED UP TO 1 WEEK" 5 "5=2ND & 3RD SESSION"
                       6 "6=1 CALL" ;
label define ADROPSES  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define ADROPSPE  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=THREE" 2 "2=ANY #" 3 "3=AS MANY AS CLIENTS WISH"
                       4 "4=IF CLIENT WISHES" ;
label define ASUPGRP   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define ALGTHSES  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=UP TO 2 MONTHS AFTER COMP"
                       2 "2=15-20 MIN UP UNTIL 5" 3 "3=UP TO 1 HOUR"
                       4 "4=UP TO 15 MIN" ;
label define AOFTNGRP  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=WHENEVER HIV +" 2 "2=MONTHLY" ;
label define AOTHREIN  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define AOTHSP    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=OUTREACH WRKRS/CASE MANAGER FOLUP"
                       2 "2=HIV FORUMS FOR HIV +"
                       3 "3=REINFORCEMENT OF INDIVIDUAL"
                       4 "4=INFORMAL CLIENT-INTERVENTION" ;
label define AINCENT   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define ADESC     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO ANSWER" 1 "1=SODA/COFFEE/SANDWICH"
                       2 "2=BUS TICKET, VAN RIDE" 3 "3=DIPLOMA AFTER ATTEND"
                       4 "4=FORMAL SES: 2 MCDONALDS COUPONS"
                       5 "5=FOOD/SURVIVAL KIT/$5 FOR TRANS"
                       6 "6=$10 MEAL VOUCHERS" 7 "7=FOOD COUPONS/BUS TICKETS"
                       8 "8=BUS PASS/HYGIENE SUBSIDY" ;
label define ASTART    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define ACOMP     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define ATOT      -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define ATOTSP    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=BONDING SESSION" 2 "2=7 DAYS AFTER PT"
                       3 "3=ASAP AFTERWARD" 4 "4=START AT STANDARD CA" ;
label define APAID     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define AGENDER   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=NO ANSWER" 2 "2=MALE" 3 "3=FEMALE" 4 "4=BOTH" ;
label define AHEDM     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define AHEDB     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define AHEDN     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define APEERCON  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define ANURSE    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define ADRGCON   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define AOTHINT   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define AOTHSPIN  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=HEALTH PSYCHOLOGY GRADUATE" 2 "2=SOCIAL WORKER"
                       3 "3=OUTREACH WORKER" ;
label define ATRANSP   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define AHIVTEST  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define AHIVCOUN  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define AURINTST  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define AOTHIS2   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=ADDITIONAL HEALTH SCREENING"
                       2 "2=ADDITIONAL INFORMATION"
                       3 "3=CASE MANAGEMENT ADVOCACY"
                       4 "4=UTILIZATION OF TIME" 5 "5=MONEY MANAGEMENT"
                       6 "6=CHANGE IN ? NORMS" 7 "7=RISK REDUCTION FOLUP" ;
label define AOTHIS1   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=ADDITIONAL HEALTH SCREENING"
                       2 "2=ADDITIONAL INFORMATION"
                       3 "3=CASE MANAGEMENT ADVOCACY"
                       4 "4=UTILIZATION OF TIME" 5 "5=MONEY MANAGEMENT"
                       6 "6=CHANGE IN ? NORMS" 7 "7=RISK REDUCTION FOLUP" ;
label define AOTHIS3   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=ADDITIONAL HEALTH SCREENING"
                       2 "2=ADDITIONAL INFORMATION"
                       3 "3=CASE MANAGEMENT ADVOCACY"
                       4 "4=UTILIZATION OF TIME" 5 "5=MONEY MANAGEMENT"
                       6 "6=CHANGE IN ? NORMS" 7 "7=RISK REDUCTION FOLUP" ;
label define AINDSZ    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=3-9" 2 "2=2-20" 8 "8=OLD NO FORM NO ANSWER" ;
label define AINDCOMP  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=INTERVENTION CHARTS"
                       2 "2=AMC DRUG NETWORKS & PART"
                       3 "3=AMC OLD FORM NO ANSWER" ;
label define LD88HIVP  -9.000 "-9 = SKIP, INELIG, NA" -8.000 "-8 = REFUSED"
                       -7.000 "-7 = DO NOT KNOW, UNSURE"
                       -6.000 "-6 = NOT APPLIC OR REFUSED"
                       -5.000 "-5 = SYSTEM MISSING"
                       -4.000 "-4 = INVALID VALUE" ;
label define LD90HIVP  -9.000 "-9 = SKIP, INELIG, NA" -8.000 "-8 = REFUSED"
                       -7.000 "-7 = DO NOT KNOW, UNSURE"
                       -6.000 "-6 = NOT APPLIC OR REFUSED"
                       -5.000 "-5 = SYSTEM MISSING"
                       -4.000 "-4 = INVALID VALUE" ;
label define LD92HIVP  -9.00 "-9 = SKIP, INELIG, NA" -8.00 "-8 = REFUSED"
                       -7.00 "-7 = DO NOT KNOW, UNSURE"
                       -6.00 "-6 = NOT APPLIC OR REFUSED"
                       -5.00 "-5 = SYSTEM MISSING" -4.00 "-4 = INVALID VALUE" ;
label define LD94HIVP  -9.00 "-9 = SKIP, INELIG, NA" -8.00 "-8 = REFUSED"
                       -7.00 "-7 = DO NOT KNOW, UNSURE"
                       -6.00 "-6 = NOT APPLIC OR REFUSED"
                       -5.00 "-5 = SYSTEM MISSING" -4.00 "-4 = INVALID VALUE" ;
label define LD96HIVP  -9.00 "-9 = SKIP, INELIG, NA" -8.00 "-8 = REFUSED"
                       -7.00 "-7 = DO NOT KNOW, UNSURE"
                       -6.00 "-6 = NOT APPLIC OR REFUSED"
                       -5.00 "-5 = SYSTEM MISSING" -4.00 "-4 = INVALID VALUE" ;
label define LD88ACCP  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY LOW" 2 "2=LOW" 3 "3=MODERATE" 4 "4=HIGH"
                       5 "5=VERY HIGH" ;
label define LD90ACCP  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY LOW" 2 "2=LOW" 3 "3=MODERATE" 4 "4=HIGH"
                       5 "5=VERY HIGH" ;
label define LD92ACCP  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY LOW" 2 "2=LOW" 3 "3=MODERATE" 4 "4=HIGH"
                       5 "5=VERY HIGH" ;
label define LD94ACCP  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY LOW" 2 "2=LOW" 3 "3=MODERATE" 4 "4=HIGH"
                       5 "5=VERY HIGH" ;
label define LD96ACCP  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY LOW" 2 "2=LOW" 3 "3=MODERATE" 4 "4=HIGH"
                       5 "5=VERY HIGH" ;
label define LD88HIVI  -9.000 "-9 = SKIP, INELIG, NA" -8.000 "-8 = REFUSED"
                       -7.000 "-7 = DO NOT KNOW, UNSURE"
                       -6.000 "-6 = NOT APPLIC OR REFUSED"
                       -5.000 "-5 = SYSTEM MISSING"
                       -4.000 "-4 = INVALID VALUE" ;
label define LD90HIVI  -9.000 "-9 = SKIP, INELIG, NA" -8.000 "-8 = REFUSED"
                       -7.000 "-7 = DO NOT KNOW, UNSURE"
                       -6.000 "-6 = NOT APPLIC OR REFUSED"
                       -5.000 "-5 = SYSTEM MISSING"
                       -4.000 "-4 = INVALID VALUE" ;
label define LD92HIVI  -9.000 "-9 = SKIP, INELIG, NA" -8.000 "-8 = REFUSED"
                       -7.000 "-7 = DO NOT KNOW, UNSURE"
                       -6.000 "-6 = NOT APPLIC OR REFUSED"
                       -5.000 "-5 = SYSTEM MISSING"
                       -4.000 "-4 = INVALID VALUE" ;
label define LD94HIVI  -9.000 "-9 = SKIP, INELIG, NA" -8.000 "-8 = REFUSED"
                       -7.000 "-7 = DO NOT KNOW, UNSURE"
                       -6.000 "-6 = NOT APPLIC OR REFUSED"
                       -5.000 "-5 = SYSTEM MISSING"
                       -4.000 "-4 = INVALID VALUE" ;
label define LD96HIVI  -9.000 "-9 = SKIP, INELIG, NA" -8.000 "-8 = REFUSED"
                       -7.000 "-7 = DO NOT KNOW, UNSURE"
                       -6.000 "-6 = NOT APPLIC OR REFUSED"
                       -5.000 "-5 = SYSTEM MISSING"
                       -4.000 "-4 = INVALID VALUE" ;
label define LD88ACCI  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY LOW" 2 "2=LOW" 3 "3=MODERATE" 4 "4=HIGH"
                       5 "5=VERY HIGH" ;
label define LD90ACCI  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY LOW" 2 "2=LOW" 3 "3=MODERATE" 4 "4=HIGH"
                       5 "5=VERY HIGH" ;
label define LD92ACCI  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY LOW" 2 "2=LOW" 3 "3=MODERATE" 4 "4=HIGH"
                       5 "5=VERY HIGH" ;
label define LD94ACCI  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY LOW" 2 "2=LOW" 3 "3=MODERATE" 4 "4=HIGH"
                       5 "5=VERY HIGH" ;
label define LD96ACCI  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY LOW" 2 "2=LOW" 3 "3=MODERATE" 4 "4=HIGH"
                       5 "5=VERY HIGH" ;
label define LD88PHAV  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD90PHAV  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD92PHAV  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD94PHAV  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD96PHAV  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD88PHUS  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY SMALL EXTENT" 2 "2=SMALL EXTENT"
                       3 "3=MODERATE EXTENT" 4 "4=LARGE EXTENT"
                       5 "5=VERY LARGE EXTENT" ;
label define LD90PHUS  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY SMALL EXTENT" 2 "2=SMALL EXTENT"
                       3 "3=MODERATE EXTENT" 4 "4=LARGE EXTENT"
                       5 "5=VERY LARGE EXTENT" ;
label define LD92PHUS  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY SMALL EXTENT" 2 "2=SMALL EXTENT"
                       3 "3=MODERATE EXTENT" 4 "4=LARGE EXTENT"
                       5 "5=VERY LARGE EXTENT" ;
label define LD94PHUS  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY SMALL EXTENT" 2 "2=SMALL EXTENT"
                       3 "3=MODERATE EXTENT" 4 "4=LARGE EXTENT"
                       5 "5=VERY LARGE EXTENT" ;
label define LD96PHUS  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY SMALL EXTENT" 2 "2=SMALL EXTENT"
                       3 "3=MODERATE EXTENT" 4 "4=LARGE EXTENT"
                       5 "5=VERY LARGE EXTENT" ;
label define LD88PHAC  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY LOW" 2 "2=LOW" 3 "3=MODERATE" 4 "4=HIGH"
                       5 "5=VERY HIGH" ;
label define LD90PHAC  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY LOW" 2 "2=LOW" 3 "3=MODERATE" 4 "4=HIGH"
                       5 "5=VERY HIGH" ;
label define LD92PHAC  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY LOW" 2 "2=LOW" 3 "3=MODERATE" 4 "4=HIGH"
                       5 "5=VERY HIGH" ;
label define LD94PHAC  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY LOW" 2 "2=LOW" 3 "3=MODERATE" 4 "4=HIGH"
                       5 "5=VERY HIGH" ;
label define LD96PHAC  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY LOW" 2 "2=LOW" 3 "3=MODERATE" 4 "4=HIGH"
                       5 "5=VERY HIGH" ;
label define LD88NEAV  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD90NEAV  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD92NEAV  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD94NEAV  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD96NEAV  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD88NEUS  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY SMALL EXTENT" 2 "2=SMALL EXTENT"
                       3 "3=MODERATE EXTENT" 4 "4=LARGE EXTENT"
                       5 "5=VERY LARGE EXTENT" ;
label define LD90NEUS  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY SMALL EXTENT" 2 "2=SMALL EXTENT"
                       3 "3=MODERATE EXTENT" 4 "4=LARGE EXTENT"
                       5 "5=VERY LARGE EXTENT" ;
label define LD92NEUS  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY SMALL EXTENT" 2 "2=SMALL EXTENT"
                       3 "3=MODERATE EXTENT" 4 "4=LARGE EXTENT"
                       5 "5=VERY LARGE EXTENT" ;
label define LD94NEUS  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY SMALL EXTENT" 2 "2=SMALL EXTENT"
                       3 "3=MODERATE EXTENT" 4 "4=LARGE EXTENT"
                       5 "5=VERY LARGE EXTENT" ;
label define LD96NEUS  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY SMALL EXTENT" 2 "2=SMALL EXTENT"
                       3 "3=MODERATE EXTENT" 4 "4=LARGE EXTENT"
                       5 "5=VERY LARGE EXTENT" ;
label define LD88NEAC  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY LOW" 2 "2=LOW" 3 "3=MODERATE" 4 "4=HIGH"
                       5 "5=VERY HIGH" ;
label define LD90NEAC  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY LOW" 2 "2=LOW" 3 "3=MODERATE" 4 "4=HIGH"
                       5 "5=VERY HIGH" ;
label define LD92NEAC  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY LOW" 2 "2=LOW" 3 "3=MODERATE" 4 "4=HIGH"
                       5 "5=VERY HIGH" ;
label define LD94NEAC  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY LOW" 2 "2=LOW" 3 "3=MODERATE" 4 "4=HIGH"
                       5 "5=VERY HIGH" ;
label define LD96NEAC  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY LOW" 2 "2=LOW" 3 "3=MODERATE" 4 "4=HIGH"
                       5 "5=VERY HIGH" ;
label define LD88DBAV  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD90DBAV  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD92DBAV  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD94DBAV  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD96DBAV  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD88DBUS  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY SMALL EXTENT" 2 "2=SMALL EXTENT"
                       3 "3=MODERATE EXTENT" 4 "4=LARGE EXTENT"
                       5 "5=VERY LARGE EXTENT" ;
label define LD90DBUS  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY SMALL EXTENT" 2 "2=SMALL EXTENT"
                       3 "3=MODERATE EXTENT" 4 "4=LARGE EXTENT"
                       5 "5=VERY LARGE EXTENT" ;
label define LD92DBUS  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY SMALL EXTENT" 2 "2=SMALL EXTENT"
                       3 "3=MODERATE EXTENT" 4 "4=LARGE EXTENT"
                       5 "5=VERY LARGE EXTENT" ;
label define LD94DBUS  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY SMALL EXTENT" 2 "2=SMALL EXTENT"
                       3 "3=MODERATE EXTENT" 4 "4=LARGE EXTENT"
                       5 "5=VERY LARGE EXTENT" ;
label define LD96DBUS  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY SMALL EXTENT" 2 "2=SMALL EXTENT"
                       3 "3=MODERATE EXTENT" 4 "4=LARGE EXTENT"
                       5 "5=VERY LARGE EXTENT" ;
label define LD88DBAC  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY LOW" 2 "2=LOW" 3 "3=MODERATE" 4 "4=HIGH"
                       5 "5=VERY HIGH" ;
label define LD90DBAC  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY LOW" 2 "2=LOW" 3 "3=MODERATE" 4 "4=HIGH"
                       5 "5=VERY HIGH" ;
label define LD92DBAC  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY LOW" 2 "2=LOW" 3 "3=MODERATE" 4 "4=HIGH"
                       5 "5=VERY HIGH" ;
label define LD94DBAC  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY LOW" 2 "2=LOW" 3 "3=MODERATE" 4 "4=HIGH"
                       5 "5=VERY HIGH" ;
label define LD96DBAC  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY LOW" 2 "2=LOW" 3 "3=MODERATE" 4 "4=HIGH"
                       5 "5=VERY HIGH" ;
label define LD88SDAV  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD90SDAV  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD92SDAV  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD94SDAV  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD96SDAV  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD88SDUS  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY SMALL EXTENT" 2 "2=SMALL EXTENT"
                       3 "3=MODERATE EXTENT" 4 "4=LARGE EXTENT"
                       5 "5=VERY LARGE EXTENT" ;
label define LD90SDUS  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY SMALL EXTENT" 2 "2=SMALL EXTENT"
                       3 "3=MODERATE EXTENT" 4 "4=LARGE EXTENT"
                       5 "5=VERY LARGE EXTENT" ;
label define LD92SDUS  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY SMALL EXTENT" 2 "2=SMALL EXTENT"
                       3 "3=MODERATE EXTENT" 4 "4=LARGE EXTENT"
                       5 "5=VERY LARGE EXTENT" ;
label define LD94SDUS  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY SMALL EXTENT" 2 "2=SMALL EXTENT"
                       3 "3=MODERATE EXTENT" 4 "4=LARGE EXTENT"
                       5 "5=VERY LARGE EXTENT" ;
label define LD96SDUS  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY SMALL EXTENT" 2 "2=SMALL EXTENT"
                       3 "3=MODERATE EXTENT" 4 "4=LARGE EXTENT"
                       5 "5=VERY LARGE EXTENT" ;
label define LD88SDAC  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY LOW" 2 "2=LOW" 3 "3=MODERATE" 4 "4=HIGH"
                       5 "5=VERY HIGH" ;
label define LD90SDAC  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY LOW" 2 "2=LOW" 3 "3=MODERATE" 4 "4=HIGH"
                       5 "5=VERY HIGH" ;
label define LD92SDAC  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY LOW" 2 "2=LOW" 3 "3=MODERATE" 4 "4=HIGH"
                       5 "5=VERY HIGH" ;
label define LD94SDAC  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY LOW" 2 "2=LOW" 3 "3=MODERATE" 4 "4=HIGH"
                       5 "5=VERY HIGH" ;
label define LD96SDAC  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY LOW" 2 "2=LOW" 3 "3=MODERATE" 4 "4=HIGH"
                       5 "5=VERY HIGH" ;
label define LD88SGAV  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD90SGAV  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD92SGAV  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD94SGAV  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD96SGAV  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD88SGUS  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY SMALL EXTENT" 2 "2=SMALL EXTENT"
                       3 "3=MODERATE EXTENT" 4 "4=LARGE EXTENT"
                       5 "5=VERY LARGE EXTENT" ;
label define LD90SGUS  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY SMALL EXTENT" 2 "2=SMALL EXTENT"
                       3 "3=MODERATE EXTENT" 4 "4=LARGE EXTENT"
                       5 "5=VERY LARGE EXTENT" ;
label define LD92SGUS  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY SMALL EXTENT" 2 "2=SMALL EXTENT"
                       3 "3=MODERATE EXTENT" 4 "4=LARGE EXTENT"
                       5 "5=VERY LARGE EXTENT" ;
label define LD94SGUS  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY SMALL EXTENT" 2 "2=SMALL EXTENT"
                       3 "3=MODERATE EXTENT" 4 "4=LARGE EXTENT"
                       5 "5=VERY LARGE EXTENT" ;
label define LD96SGUS  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY SMALL EXTENT" 2 "2=SMALL EXTENT"
                       3 "3=MODERATE EXTENT" 4 "4=LARGE EXTENT"
                       5 "5=VERY LARGE EXTENT" ;
label define LD88SGAC  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY LOW" 2 "2=LOW" 3 "3=MODERATE" 4 "4=HIGH"
                       5 "5=VERY HIGH" ;
label define LD90SGAC  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY LOW" 2 "2=LOW" 3 "3=MODERATE" 4 "4=HIGH"
                       5 "5=VERY HIGH" ;
label define LD92SGAC  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY LOW" 2 "2=LOW" 3 "3=MODERATE" 4 "4=HIGH"
                       5 "5=VERY HIGH" ;
label define LD94SGAC  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY LOW" 2 "2=LOW" 3 "3=MODERATE" 4 "4=HIGH"
                       5 "5=VERY HIGH" ;
label define LD96SGAC  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY LOW" 2 "2=LOW" 3 "3=MODERATE" 4 "4=HIGH"
                       5 "5=VERY HIGH" ;
label define LD88NE01  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD90NE01  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD92NE01  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD94NE01  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD96NE01  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD88NE02  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD90NE02  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD92NE02  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD94NE02  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD96NE02  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD88NE03  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD90NE03  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD92NE03  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD94NE03  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD96NE03  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD88NEC1  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD90NEC1  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD92NEC1  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD94NEC1  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD96NEC1  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD88NEC2  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD90NEC2  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD92NEC2  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD94NEC2  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD96NEC2  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD90OP1   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD92OP1   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD94OP1   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD96OP1   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD92OP2   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD94OP2   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD96OP2   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD94OP3   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD96OP3   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD90MAX1  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD92MAX1  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD94MAX1  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD96MAX1  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD94MAX2  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD96MAX2  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD94MAX3  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD96MAX3  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD90ANN1  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define LD92ANN1  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define LD94ANN1  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define LD96ANN1  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define LD96ANN2  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define LD88LAWS  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD90LAWS  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD92LAWS  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD94LAWS  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD96LAWS  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD88LAWL  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD90LAWL  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD92LAWL  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD94LAWL  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD96LAWL  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD88NORX  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NONE" 1 "1=VERY FEW" 2 "2=FEW" 3 "3=MANY" ;
label define LD90NORX  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NONE" 1 "1=VERY FEW" 2 "2=FEW" 3 "3=MANY" ;
label define LD92NORX  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NONE" 1 "1=VERY FEW" 2 "2=FEW" 3 "3=MANY" ;
label define LD94NORX  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NONE" 1 "1=VERY FEW" 2 "2=FEW" 3 "3=MANY" ;
label define LD96NORX  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NONE" 1 "1=VERY FEW" 2 "2=FEW" 3 "3=MANY" ;
label define LD88MINP  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NONE" 1 "1=FEW" 2 "2=MANY" ;
label define LD90MINP  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NONE" 1 "1=FEW" 2 "2=MANY" ;
label define LD92MINP  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NONE" 1 "1=FEW" 2 "2=MANY" ;
label define LD94MINP  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NONE" 1 "1=FEW" 2 "2=MANY" ;
label define LD96MINP  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NONE" 1 "1=FEW" 2 "2=MANY" ;
label define LD88ID    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD90ID    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD92ID    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD94ID    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD96ID    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD88SIG   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD90SIG   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD92SIG   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD94SIG   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD96SIG   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD88PRDB  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD90PRDB  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD92PRDB  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD94PRDB  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD96PRDB  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD88DTPP  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD90DTPP  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD92DTPP  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD94DTPP  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD96DTPP  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD88DTPR  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=NOT AT ALL" 2 "2=VERY SMALL EXTENT"
                       3 "3=SMALL EXTENT" 4 "4=MODERATE EXTENT"
                       5 "5=LARGE EXTENT" 6 "6=VERY LARGE EXTENT" ;
label define LD90DTPR  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=NOT AT ALL" 2 "2=VERY SMALL EXTENT"
                       3 "3=SMALL EXTENT" 4 "4=MODERATE EXTENT"
                       5 "5=LARGE EXTENT" 6 "6=VERY LARGE EXTENT" ;
label define LD92DTPR  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=NOT AT ALL" 2 "2=VERY SMALL EXTENT"
                       3 "3=SMALL EXTENT" 4 "4=MODERATE EXTENT"
                       5 "5=LARGE EXTENT" 6 "6=VERY LARGE EXTENT" ;
label define LD94DTPR  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=NOT AT ALL" 2 "2=VERY SMALL EXTENT"
                       3 "3=SMALL EXTENT" 4 "4=MODERATE EXTENT"
                       5 "5=LARGE EXTENT" 6 "6=VERY LARGE EXTENT" ;
label define LD96DTPR  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=NOT AT ALL" 2 "2=VERY SMALL EXTENT"
                       3 "3=SMALL EXTENT" 4 "4=MODERATE EXTENT"
                       5 "5=LARGE EXTENT" 6 "6=VERY LARGE EXTENT" ;
label define LD88HTCP  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD90HTCP  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD92HTCP  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD94HTCP  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD96HTCP  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD88HTCR  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=NOT AT ALL" 2 "2=VERY SMALL EXTENT"
                       3 "3=SMALL EXTENT" 4 "4=MODERATE EXTENT"
                       5 "5=LARGE EXTENT" 6 "6=VERY LARGE EXTENT" ;
label define LD90HTCR  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=NOT AT ALL" 2 "2=VERY SMALL EXTENT"
                       3 "3=SMALL EXTENT" 4 "4=MODERATE EXTENT"
                       5 "5=LARGE EXTENT" 6 "6=VERY LARGE EXTENT" ;
label define LD92HTCR  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=NOT AT ALL" 2 "2=VERY SMALL EXTENT"
                       3 "3=SMALL EXTENT" 4 "4=MODERATE EXTENT"
                       5 "5=LARGE EXTENT" 6 "6=VERY LARGE EXTENT" ;
label define LD94HTCR  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=NOT AT ALL" 2 "2=VERY SMALL EXTENT"
                       3 "3=SMALL EXTENT" 4 "4=MODERATE EXTENT"
                       5 "5=LARGE EXTENT" 6 "6=VERY LARGE EXTENT" ;
label define LD96HTCR  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=NOT AT ALL" 2 "2=VERY SMALL EXTENT"
                       3 "3=SMALL EXTENT" 4 "4=MODERATE EXTENT"
                       5 "5=LARGE EXTENT" 6 "6=VERY LARGE EXTENT" ;
label define LD88STDP  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD90STDP  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD92STDP  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD94STDP  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD96STDP  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD88STDR  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=NOT AT ALL" 2 "2=VERY SMALL EXTENT"
                       3 "3=SMALL EXTENT" 4 "4=MODERATE EXTENT"
                       5 "5=LARGE EXTENT" 6 "6=VERY LARGE EXTENT" ;
label define LD90STDR  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=NOT AT ALL" 2 "2=VERY SMALL EXTENT"
                       3 "3=SMALL EXTENT" 4 "4=MODERATE EXTENT"
                       5 "5=LARGE EXTENT" 6 "6=VERY LARGE EXTENT" ;
label define LD92STDR  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=NOT AT ALL" 2 "2=VERY SMALL EXTENT"
                       3 "3=SMALL EXTENT" 4 "4=MODERATE EXTENT"
                       5 "5=LARGE EXTENT" 6 "6=VERY LARGE EXTENT" ;
label define LD94STDR  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=NOT AT ALL" 2 "2=VERY SMALL EXTENT"
                       3 "3=SMALL EXTENT" 4 "4=MODERATE EXTENT"
                       5 "5=LARGE EXTENT" 6 "6=VERY LARGE EXTENT" ;
label define LD96STDR  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=NOT AT ALL" 2 "2=VERY SMALL EXTENT"
                       3 "3=SMALL EXTENT" 4 "4=MODERATE EXTENT"
                       5 "5=LARGE EXTENT" 6 "6=VERY LARGE EXTENT" ;
label define LD88HOPP  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD90HOPP  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD92HOPP  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD94HOPP  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD96HOPP  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD88HOPR  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=NOT AT ALL" 2 "2=VERY SMALL EXTENT"
                       3 "3=SMALL EXTENT" 4 "4=MODERATE EXTENT"
                       5 "5=LARGE EXTENT" 6 "6=VERY LARGE EXTENT" ;
label define LD90HOPR  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=NOT AT ALL" 2 "2=VERY SMALL EXTENT"
                       3 "3=SMALL EXTENT" 4 "4=MODERATE EXTENT"
                       5 "5=LARGE EXTENT" 6 "6=VERY LARGE EXTENT" ;
label define LD92HOPR  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=NOT AT ALL" 2 "2=VERY SMALL EXTENT"
                       3 "3=SMALL EXTENT" 4 "4=MODERATE EXTENT"
                       5 "5=LARGE EXTENT" 6 "6=VERY LARGE EXTENT" ;
label define LD94HOPR  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=NOT AT ALL" 2 "2=VERY SMALL EXTENT"
                       3 "3=SMALL EXTENT" 4 "4=MODERATE EXTENT"
                       5 "5=LARGE EXTENT" 6 "6=VERY LARGE EXTENT" ;
label define LD96HOPR  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=NOT AT ALL" 2 "2=VERY SMALL EXTENT"
                       3 "3=SMALL EXTENT" 4 "4=MODERATE EXTENT"
                       5 "5=LARGE EXTENT" 6 "6=VERY LARGE EXTENT" ;
label define LD88OOPP  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD90OOPP  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD92OOPP  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD94OOPP  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD96OOPP  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD88OOPR  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=NOT AT ALL" 2 "2=VERY SMALL EXTENT"
                       3 "3=SMALL EXTENT" 4 "4=MODERATE EXTENT"
                       5 "5=LARGE EXTENT" 6 "6=VERY LARGE EXTENT" ;
label define LD90OOPR  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=NOT AT ALL" 2 "2=VERY SMALL EXTENT"
                       3 "3=SMALL EXTENT" 4 "4=MODERATE EXTENT"
                       5 "5=LARGE EXTENT" 6 "6=VERY LARGE EXTENT" ;
label define LD92OOPR  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=NOT AT ALL" 2 "2=VERY SMALL EXTENT"
                       3 "3=SMALL EXTENT" 4 "4=MODERATE EXTENT"
                       5 "5=LARGE EXTENT" 6 "6=VERY LARGE EXTENT" ;
label define LD94OOPR  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=NOT AT ALL" 2 "2=VERY SMALL EXTENT"
                       3 "3=SMALL EXTENT" 4 "4=MODERATE EXTENT"
                       5 "5=LARGE EXTENT" 6 "6=VERY LARGE EXTENT" ;
label define LD96OOPR  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=NOT AT ALL" 2 "2=VERY SMALL EXTENT"
                       3 "3=SMALL EXTENT" 4 "4=MODERATE EXTENT"
                       5 "5=LARGE EXTENT" 6 "6=VERY LARGE EXTENT" ;
label define LD88HCMP  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD90HCMP  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD92HCMP  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD94HCMP  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD96HCMP  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD88HCMR  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=NOT AT ALL" 2 "2=VERY SMALL EXTENT"
                       3 "3=SMALL EXTENT" 4 "4=MODERATE EXTENT"
                       5 "5=LARGE EXTENT" 6 "6=VERY LARGE EXTENT" ;
label define LD90HCMR  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=NOT AT ALL" 2 "2=VERY SMALL EXTENT"
                       3 "3=SMALL EXTENT" 4 "4=MODERATE EXTENT"
                       5 "5=LARGE EXTENT" 6 "6=VERY LARGE EXTENT" ;
label define LD92HCMR  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=NOT AT ALL" 2 "2=VERY SMALL EXTENT"
                       3 "3=SMALL EXTENT" 4 "4=MODERATE EXTENT"
                       5 "5=LARGE EXTENT" 6 "6=VERY LARGE EXTENT" ;
label define LD94HCMR  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=NOT AT ALL" 2 "2=VERY SMALL EXTENT"
                       3 "3=SMALL EXTENT" 4 "4=MODERATE EXTENT"
                       5 "5=LARGE EXTENT" 6 "6=VERY LARGE EXTENT" ;
label define LD96HCMR  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=NOT AT ALL" 2 "2=VERY SMALL EXTENT"
                       3 "3=SMALL EXTENT" 4 "4=MODERATE EXTENT"
                       5 "5=LARGE EXTENT" 6 "6=VERY LARGE EXTENT" ;
label define LD88OCMP  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD90OCMP  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD92OCMP  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD94OCMP  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD96OCMP  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD88OCMR  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=NOT AT ALL" 2 "2=VERY SMALL EXTENT"
                       3 "3=SMALL EXTENT" 4 "4=MODERATE EXTENT"
                       5 "5=LARGE EXTENT" 6 "6=VERY LARGE EXTENT" ;
label define LD90OCMR  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=NOT AT ALL" 2 "2=VERY SMALL EXTENT"
                       3 "3=SMALL EXTENT" 4 "4=MODERATE EXTENT"
                       5 "5=LARGE EXTENT" 6 "6=VERY LARGE EXTENT" ;
label define LD92OCMR  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=NOT AT ALL" 2 "2=VERY SMALL EXTENT"
                       3 "3=SMALL EXTENT" 4 "4=MODERATE EXTENT"
                       5 "5=LARGE EXTENT" 6 "6=VERY LARGE EXTENT" ;
label define LD94OCMR  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=NOT AT ALL" 2 "2=VERY SMALL EXTENT"
                       3 "3=SMALL EXTENT" 4 "4=MODERATE EXTENT"
                       5 "5=LARGE EXTENT" 6 "6=VERY LARGE EXTENT" ;
label define LD96OCMR  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=NOT AT ALL" 2 "2=VERY SMALL EXTENT"
                       3 "3=SMALL EXTENT" 4 "4=MODERATE EXTENT"
                       5 "5=LARGE EXTENT" 6 "6=VERY LARGE EXTENT" ;
label define LD88MSP   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD90MSP   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD92MSP   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD94MSP   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD96MSP   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD88MSR   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=NOT AT ALL" 2 "2=VERY SMALL EXTENT"
                       3 "3=SMALL EXTENT" 4 "4=MODERATE EXTENT"
                       5 "5=LARGE EXTENT" 6 "6=VERY LARGE EXTENT" ;
label define LD90MSR   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=NOT AT ALL" 2 "2=VERY SMALL EXTENT"
                       3 "3=SMALL EXTENT" 4 "4=MODERATE EXTENT"
                       5 "5=LARGE EXTENT" 6 "6=VERY LARGE EXTENT" ;
label define LD92MSR   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=NOT AT ALL" 2 "2=VERY SMALL EXTENT"
                       3 "3=SMALL EXTENT" 4 "4=MODERATE EXTENT"
                       5 "5=LARGE EXTENT" 6 "6=VERY LARGE EXTENT" ;
label define LD94MSR   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=NOT AT ALL" 2 "2=VERY SMALL EXTENT"
                       3 "3=SMALL EXTENT" 4 "4=MODERATE EXTENT"
                       5 "5=LARGE EXTENT" 6 "6=VERY LARGE EXTENT" ;
label define LD96MSR   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=NOT AT ALL" 2 "2=VERY SMALL EXTENT"
                       3 "3=SMALL EXTENT" 4 "4=MODERATE EXTENT"
                       5 "5=LARGE EXTENT" 6 "6=VERY LARGE EXTENT" ;
label define LD88HLP   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD90HLP   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD92HLP   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD94HLP   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD96HLP   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD88HLR   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=NOT AT ALL" 2 "2=VERY SMALL EXTENT"
                       3 "3=SMALL EXTENT" 4 "4=MODERATE EXTENT"
                       5 "5=LARGE EXTENT" 6 "6=VERY LARGE EXTENT" ;
label define LD90HLR   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=NOT AT ALL" 2 "2=VERY SMALL EXTENT"
                       3 "3=SMALL EXTENT" 4 "4=MODERATE EXTENT"
                       5 "5=LARGE EXTENT" 6 "6=VERY LARGE EXTENT" ;
label define LD92HLR   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=NOT AT ALL" 2 "2=VERY SMALL EXTENT"
                       3 "3=SMALL EXTENT" 4 "4=MODERATE EXTENT"
                       5 "5=LARGE EXTENT" 6 "6=VERY LARGE EXTENT" ;
label define LD94HLR   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=NOT AT ALL" 2 "2=VERY SMALL EXTENT"
                       3 "3=SMALL EXTENT" 4 "4=MODERATE EXTENT"
                       5 "5=LARGE EXTENT" 6 "6=VERY LARGE EXTENT" ;
label define LD96HLR   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=NOT AT ALL" 2 "2=VERY SMALL EXTENT"
                       3 "3=SMALL EXTENT" 4 "4=MODERATE EXTENT"
                       5 "5=LARGE EXTENT" 6 "6=VERY LARGE EXTENT" ;
label define LD88OIPP  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD90OIPP  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD92OIPP  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD94OIPP  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD96OIPP  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD88OIPR  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=NOT AT ALL" 2 "2=VERY SMALL EXTENT"
                       3 "3=SMALL EXTENT" 4 "4=MODERATE EXTENT"
                       5 "5=LARGE EXTENT" 6 "6=VERY LARGE EXTENT" ;
label define LD90OIPR  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=NOT AT ALL" 2 "2=VERY SMALL EXTENT"
                       3 "3=SMALL EXTENT" 4 "4=MODERATE EXTENT"
                       5 "5=LARGE EXTENT" 6 "6=VERY LARGE EXTENT" ;
label define LD92OIPR  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=NOT AT ALL" 2 "2=VERY SMALL EXTENT"
                       3 "3=SMALL EXTENT" 4 "4=MODERATE EXTENT"
                       5 "5=LARGE EXTENT" 6 "6=VERY LARGE EXTENT" ;
label define LD94OIPR  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=NOT AT ALL" 2 "2=VERY SMALL EXTENT"
                       3 "3=SMALL EXTENT" 4 "4=MODERATE EXTENT"
                       5 "5=LARGE EXTENT" 6 "6=VERY LARGE EXTENT" ;
label define LD96OIPR  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=NOT AT ALL" 2 "2=VERY SMALL EXTENT"
                       3 "3=SMALL EXTENT" 4 "4=MODERATE EXTENT"
                       5 "5=LARGE EXTENT" 6 "6=VERY LARGE EXTENT" ;
label define LDPOPEST  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define LD88IDU   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define LD88CONF  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY LOW" 2 "2=LOW" 3 "3=MODERATE" 4 "4=HIGH"
                       5 "5=VERY HIGH" ;
label define LD88GEO   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=SMALL EXTENT" 2 "2=MODERATE EXTENT"
                       3 "3=GREAT EXTENT" ;
label define LD88TRAN  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY BAD" 2 "2=BAD" 3 "3=MODERATE" 4 "4=GOOD"
                       5 "5=VERY GOOD" ;
label define LD88IMM   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY SMALL EXTENT" 2 "2=SMALL EXTENT"
                       3 "3=MODERATE EXTENT" 4 "4=LARGE EXTENT"
                       5 "5=VERY LARGE EXTENT" ;
label define LD88EMI   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY SMALL EXTENT" 2 "2=SMALL EXTENT"
                       3 "3=MODERATE EXTENT" 4 "4=LARGE EXTENT"
                       5 "5=VERY LARGE EXTENT" ;
label define LD90IDU   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define LD90CONF  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY LOW" 2 "2=LOW" 3 "3=MODERATE" 4 "4=HIGH"
                       5 "5=VERY HIGH" ;
label define LD90GEO   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=SMALL EXTENT" 2 "2=MODERATE EXTENT"
                       3 "3=GREAT EXTENT" ;
label define LD90TRAN  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY BAD" 2 "2=BAD" 3 "3=MODERATE" 4 "4=GOOD"
                       5 "5=VERY GOOD" ;
label define LD90IMM   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY SMALL EXTENT" 2 "2=SMALL EXTENT"
                       3 "3=MODERATE EXTENT" 4 "4=LARGE EXTENT"
                       5 "5=VERY LARGE EXTENT" ;
label define LD90EMI   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY SMALL EXTENT" 2 "2=SMALL EXTENT"
                       3 "3=MODERATE EXTENT" 4 "4=LARGE EXTENT"
                       5 "5=VERY LARGE EXTENT" ;
label define LD92IDU   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define LD92CONF  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY LOW" 2 "2=LOW" 3 "3=MODERATE" 4 "4=HIGH"
                       5 "5=VERY HIGH" ;
label define LD92GEO   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=SMALL EXTENT" 2 "2=MODERATE EXTENT"
                       3 "3=GREAT EXTENT" ;
label define LD92TRAN  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY BAD" 2 "2=BAD" 3 "3=MODERATE" 4 "4=GOOD"
                       5 "5=VERY GOOD" ;
label define LD92IMM   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY SMALL EXTENT" 2 "2=SMALL EXTENT"
                       3 "3=MODERATE EXTENT" 4 "4=LARGE EXTENT"
                       5 "5=VERY LARGE EXTENT" ;
label define LD92EMI   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY SMALL EXTENT" 2 "2=SMALL EXTENT"
                       3 "3=MODERATE EXTENT" 4 "4=LARGE EXTENT"
                       5 "5=VERY LARGE EXTENT" ;
label define LD94IDU   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define LD94CONF  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY LOW" 2 "2=LOW" 3 "3=MODERATE" 4 "4=HIGH"
                       5 "5=VERY HIGH" ;
label define LD94GEO   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=SMALL EXTENT" 2 "2=MODERATE EXTENT"
                       3 "3=GREAT EXTENT" ;
label define LD94TRAN  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY BAD" 2 "2=BAD" 3 "3=MODERATE" 4 "4=GOOD"
                       5 "5=VERY GOOD" ;
label define LD94IMM   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY SMALL EXTENT" 2 "2=SMALL EXTENT"
                       3 "3=MODERATE EXTENT" 4 "4=LARGE EXTENT"
                       5 "5=VERY LARGE EXTENT" ;
label define LD94EMI   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY SMALL EXTENT" 2 "2=SMALL EXTENT"
                       3 "3=MODERATE EXTENT" 4 "4=LARGE EXTENT"
                       5 "5=VERY LARGE EXTENT" ;
label define LD96IDU   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define LD96CONF  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY LOW" 2 "2=LOW" 3 "3=MODERATE" 4 "4=HIGH"
                       5 "5=VERY HIGH" ;
label define LD96GEO   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=SMALL EXTENT" 2 "2=MODERATE EXTENT"
                       3 "3=GREAT EXTENT" ;
label define LD96TRAN  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY BAD" 2 "2=BAD" 3 "3=MODERATE" 4 "4=GOOD"
                       5 "5=VERY GOOD" ;
label define LD96IMM   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY SMALL EXTENT" 2 "2=SMALL EXTENT"
                       3 "3=MODERATE EXTENT" 4 "4=LARGE EXTENT"
                       5 "5=VERY LARGE EXTENT" ;
label define LD96EMI   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY SMALL EXTENT" 2 "2=SMALL EXTENT"
                       3 "3=MODERATE EXTENT" 4 "4=LARGE EXTENT"
                       5 "5=VERY LARGE EXTENT" ;
label define LD88HL    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD88JAIL  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD88TRNS  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD88INST  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD90HL    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD90JAIL  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD90TRNS  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD90INST  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD92HL    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD92JAIL  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD92TRNS  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD92INST  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD94HL    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD94JAIL  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD94TRNS  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD94INST  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD96HL    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD96JAIL  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD96TRNS  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD96INST  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD88MALE  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD90MALE  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD92MALE  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD94MALE  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD96MALE  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD88FEM   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD90FEM   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD92FEM   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD94FEM   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD96FEM   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD88U25   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD90U25   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD92U25   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD94U25   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD96U25   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD882535  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD902535  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD922535  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD942535  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD962535  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD88G35   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD90G35   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD92G35   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD94G35   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD96G35   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD88BLA   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD90BLA   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD92BLA   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD94BLA   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD96BLA   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD88WHIT  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD90WHIT  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD92WHIT  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD94WHIT  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD96WHIT  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD88HISP  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD90HISP  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD92HISP  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD94HISP  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD96HISP  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD88OTHR  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD90OTHR  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD92OTHR  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD94OTHR  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD96OTHR  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD88OTH   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD90OTH   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD92OTH   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD94OTH   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD96OTH   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD88HER   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define LD90HER   -9.0 "-9 = SKIP, INELIG, NA" -8.0 "-8 = REFUSED"
                       -7.0 "-7 = DO NOT KNOW, UNSURE"
                       -6.0 "-6 = NOT APPLIC OR REFUSED"
                       -5.0 "-5 = SYSTEM MISSING" -4.0 "-4 = INVALID VALUE" ;
label define LD92HER   -9.0 "-9 = SKIP, INELIG, NA" -8.0 "-8 = REFUSED"
                       -7.0 "-7 = DO NOT KNOW, UNSURE"
                       -6.0 "-6 = NOT APPLIC OR REFUSED"
                       -5.0 "-5 = SYSTEM MISSING" -4.0 "-4 = INVALID VALUE" ;
label define LD94HER   -9.0 "-9 = SKIP, INELIG, NA" -8.0 "-8 = REFUSED"
                       -7.0 "-7 = DO NOT KNOW, UNSURE"
                       -6.0 "-6 = NOT APPLIC OR REFUSED"
                       -5.0 "-5 = SYSTEM MISSING" -4.0 "-4 = INVALID VALUE" ;
label define LD96HER   -9.0 "-9 = SKIP, INELIG, NA" -8.0 "-8 = REFUSED"
                       -7.0 "-7 = DO NOT KNOW, UNSURE"
                       -6.0 "-6 = NOT APPLIC OR REFUSED"
                       -5.0 "-5 = SYSTEM MISSING" -4.0 "-4 = INVALID VALUE" ;
label define LD88COC   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define LD90COC   -9.0 "-9 = SKIP, INELIG, NA" -8.0 "-8 = REFUSED"
                       -7.0 "-7 = DO NOT KNOW, UNSURE"
                       -6.0 "-6 = NOT APPLIC OR REFUSED"
                       -5.0 "-5 = SYSTEM MISSING" -4.0 "-4 = INVALID VALUE" ;
label define LD92COC   -9.0 "-9 = SKIP, INELIG, NA" -8.0 "-8 = REFUSED"
                       -7.0 "-7 = DO NOT KNOW, UNSURE"
                       -6.0 "-6 = NOT APPLIC OR REFUSED"
                       -5.0 "-5 = SYSTEM MISSING" -4.0 "-4 = INVALID VALUE" ;
label define LD94COC   -9.0 "-9 = SKIP, INELIG, NA" -8.0 "-8 = REFUSED"
                       -7.0 "-7 = DO NOT KNOW, UNSURE"
                       -6.0 "-6 = NOT APPLIC OR REFUSED"
                       -5.0 "-5 = SYSTEM MISSING" -4.0 "-4 = INVALID VALUE" ;
label define LD96COC   -9.0 "-9 = SKIP, INELIG, NA" -8.0 "-8 = REFUSED"
                       -7.0 "-7 = DO NOT KNOW, UNSURE"
                       -6.0 "-6 = NOT APPLIC OR REFUSED"
                       -5.0 "-5 = SYSTEM MISSING" -4.0 "-4 = INVALID VALUE" ;
label define LD88SPED  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define LD90SPED  -9.0 "-9 = SKIP, INELIG, NA" -8.0 "-8 = REFUSED"
                       -7.0 "-7 = DO NOT KNOW, UNSURE"
                       -6.0 "-6 = NOT APPLIC OR REFUSED"
                       -5.0 "-5 = SYSTEM MISSING" -4.0 "-4 = INVALID VALUE" ;
label define LD92SPED  -9.0 "-9 = SKIP, INELIG, NA" -8.0 "-8 = REFUSED"
                       -7.0 "-7 = DO NOT KNOW, UNSURE"
                       -6.0 "-6 = NOT APPLIC OR REFUSED"
                       -5.0 "-5 = SYSTEM MISSING" -4.0 "-4 = INVALID VALUE" ;
label define LD94SPED  -9.0 "-9 = SKIP, INELIG, NA" -8.0 "-8 = REFUSED"
                       -7.0 "-7 = DO NOT KNOW, UNSURE"
                       -6.0 "-6 = NOT APPLIC OR REFUSED"
                       -5.0 "-5 = SYSTEM MISSING" -4.0 "-4 = INVALID VALUE" ;
label define LD96SPED  -9.0 "-9 = SKIP, INELIG, NA" -8.0 "-8 = REFUSED"
                       -7.0 "-7 = DO NOT KNOW, UNSURE"
                       -6.0 "-6 = NOT APPLIC OR REFUSED"
                       -5.0 "-5 = SYSTEM MISSING" -4.0 "-4 = INVALID VALUE" ;
label define LD88METH  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define LD90METH  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define LD92METH  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define LD94METH  -9.0 "-9 = SKIP, INELIG, NA" -8.0 "-8 = REFUSED"
                       -7.0 "-7 = DO NOT KNOW, UNSURE"
                       -6.0 "-6 = NOT APPLIC OR REFUSED"
                       -5.0 "-5 = SYSTEM MISSING" -4.0 "-4 = INVALID VALUE" ;
label define LD96METH  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define LD88OTDR  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define LD90OTDR  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define LD92OTDR  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define LD94OTDR  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define LD96OTDR  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define LD88CON1  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY LOW" 2 "2=LOW" 3 "3=MODERATE" 4 "4=HIGH"
                       5 "5=VERY HIGH" ;
label define LD90CON1  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY LOW" 2 "2=LOW" 3 "3=MODERATE" 4 "4=HIGH"
                       5 "5=VERY HIGH" ;
label define LD92CON1  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY LOW" 2 "2=LOW" 3 "3=MODERATE" 4 "4=HIGH"
                       5 "5=VERY HIGH" ;
label define LD94CON1  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY LOW" 2 "2=LOW" 3 "3=MODERATE" 4 "4=HIGH"
                       5 "5=VERY HIGH" ;
label define LD96CON1  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY LOW" 2 "2=LOW" 3 "3=MODERATE" 4 "4=HIGH"
                       5 "5=VERY HIGH" ;
label define LD88HERA  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD90HERA  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD92HERA  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD94HERA  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD96HERA  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD88COCA  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD90COCA  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD92COCA  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD94COCA  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD96COCA  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD88SPDA  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD90SPDA  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD92SPDA  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD94SPDA  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD96SPDA  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD88META  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD90META  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD92META  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD94META  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD96META  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD88OTHA  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD90OTHA  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD92OTHA  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD94OTHA  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD96OTHA  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD88HERP  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD90HERP  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD92HERP  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD94HERP  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD96HERP  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD88COCP  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD90COCP  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD92COCP  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD94COCP  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD96COCP  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD88SPDP  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD90SPDP  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD92SPDP  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD94SPDP  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD96SPDP  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD88METP  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD90METP  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD92METP  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD94METP  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD96METP  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD88OTHP  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD90OTHP  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD92OTHP  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD94OTHP  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD96OTHP  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD88POP   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define LD90POP   -9.0 "-9 = SKIP, INELIG, NA" -8.0 "-8 = REFUSED"
                       -7.0 "-7 = DO NOT KNOW, UNSURE"
                       -6.0 "-6 = NOT APPLIC OR REFUSED"
                       -5.0 "-5 = SYSTEM MISSING" -4.0 "-4 = INVALID VALUE" ;
label define LD92POP   -9.0 "-9 = SKIP, INELIG, NA" -8.0 "-8 = REFUSED"
                       -7.0 "-7 = DO NOT KNOW, UNSURE"
                       -6.0 "-6 = NOT APPLIC OR REFUSED"
                       -5.0 "-5 = SYSTEM MISSING" -4.0 "-4 = INVALID VALUE" ;
label define LD94POP   -9.0 "-9 = SKIP, INELIG, NA" -8.0 "-8 = REFUSED"
                       -7.0 "-7 = DO NOT KNOW, UNSURE"
                       -6.0 "-6 = NOT APPLIC OR REFUSED"
                       -5.0 "-5 = SYSTEM MISSING" -4.0 "-4 = INVALID VALUE" ;
label define LD96POP   -9.0 "-9 = SKIP, INELIG, NA" -8.0 "-8 = REFUSED"
                       -7.0 "-7 = DO NOT KNOW, UNSURE"
                       -6.0 "-6 = NOT APPLIC OR REFUSED"
                       -5.0 "-5 = SYSTEM MISSING" -4.0 "-4 = INVALID VALUE" ;
label define LD88CON2  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY LOW" 2 "2=LOW" 3 "3=MODERATE" 4 "4=HIGH"
                       5 "5=VERY HIGH" ;
label define LD90CON2  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY LOW" 2 "2=LOW" 3 "3=MODERATE" 4 "4=HIGH"
                       5 "5=VERY HIGH" ;
label define LD92CON2  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY LOW" 2 "2=LOW" 3 "3=MODERATE" 4 "4=HIGH"
                       5 "5=VERY HIGH" ;
label define LD94CON2  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY LOW" 2 "2=LOW" 3 "3=MODERATE" 4 "4=HIGH"
                       5 "5=VERY HIGH" ;
label define LD96CON2  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY LOW" 2 "2=LOW" 3 "3=MODERATE" 4 "4=HIGH"
                       5 "5=VERY HIGH" ;
label define LD88GAL   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=SMALL EXTENT" 2 "2=MODERATE EXTENT"
                       3 "3=GREAT EXTENT" ;
label define LD90GAL   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=SMALL EXTENT" 2 "2=MODERATE EXTENT"
                       3 "3=GREAT EXTENT" ;
label define LD92GAL   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=SMALL EXTENT" 2 "2=MODERATE EXTENT"
                       3 "3=GREAT EXTENT" ;
label define LD94GAL   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=SMALL EXTENT" 2 "2=MODERATE EXTENT"
                       3 "3=GREAT EXTENT" ;
label define LD96GAL   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=SMALL EXTENT" 2 "2=MODERATE EXTENT"
                       3 "3=GREAT EXTENT" ;
label define LD88NGAL  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD90NGAL  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD92NGAL  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD94NGAL  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD96NGAL  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD88DISP  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD90DISP  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD92DISP  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD94DISP  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD96DISP  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO" 1 "1=YES" ;
label define LD88HAR   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY SMALL EXTENT" 2 "2=SMALL EXTENT"
                       3 "3=MODERATE EXTENT" 4 "4=LARGE EXTENT"
                       5 "5=VERY LARGE EXTENT" ;
label define LD90HAR   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY SMALL EXTENT" 2 "2=SMALL EXTENT"
                       3 "3=MODERATE EXTENT" 4 "4=LARGE EXTENT"
                       5 "5=VERY LARGE EXTENT" ;
label define LD92HAR   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY SMALL EXTENT" 2 "2=SMALL EXTENT"
                       3 "3=MODERATE EXTENT" 4 "4=LARGE EXTENT"
                       5 "5=VERY LARGE EXTENT" ;
label define LD94HAR   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY SMALL EXTENT" 2 "2=SMALL EXTENT"
                       3 "3=MODERATE EXTENT" 4 "4=LARGE EXTENT"
                       5 "5=VERY LARGE EXTENT" ;
label define LD96HAR   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY SMALL EXTENT" 2 "2=SMALL EXTENT"
                       3 "3=MODERATE EXTENT" 4 "4=LARGE EXTENT"
                       5 "5=VERY LARGE EXTENT" ;
label define LD88INIT  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=SMALL EXTENT" 2 "2=MODERATE EXTENT"
                       3 "3=GREAT EXTENT" ;
label define LD90INIT  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=SMALL EXTENT" 2 "2=MODERATE EXTENT"
                       3 "3=GREAT EXTENT" ;
label define LD92INIT  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=SMALL EXTENT" 2 "2=MODERATE EXTENT"
                       3 "3=GREAT EXTENT" ;
label define LD94INIT  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=SMALL EXTENT" 2 "2=MODERATE EXTENT"
                       3 "3=GREAT EXTENT" ;
label define LD96INIT  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=SMALL EXTENT" 2 "2=MODERATE EXTENT"
                       3 "3=GREAT EXTENT" ;
label define LD88NINI  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD90NINI  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD92NINI  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD94NINI  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD96NINI  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       0 "0=NO CHANGE" 1 "1=INCREASE" 2 "2=DECREASE" ;
label define LD88CON3  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY LOW" 2 "2=LOW" 3 "3=MODERATE" 4 "4=HIGH"
                       5 "5=VERY HIGH" ;
label define LD90CON3  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY LOW" 2 "2=LOW" 3 "3=MODERATE" 4 "4=HIGH"
                       5 "5=VERY HIGH" ;
label define LD92CON3  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY LOW" 2 "2=LOW" 3 "3=MODERATE" 4 "4=HIGH"
                       5 "5=VERY HIGH" ;
label define LD94CON3  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY LOW" 2 "2=LOW" 3 "3=MODERATE" 4 "4=HIGH"
                       5 "5=VERY HIGH" ;
label define LD96CON3  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY LOW" 2 "2=LOW" 3 "3=MODERATE" 4 "4=HIGH"
                       5 "5=VERY HIGH" ;
label define LD88AVAI  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY SMALL EXTENT" 2 "2=SMALL EXTENT"
                       3 "3=MODERATE EXTENT" 4 "4=LARGE EXTENT"
                       5 "5=VERY LARGE EXTENT" ;
label define LD90AVAI  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY SMALL EXTENT" 2 "2=SMALL EXTENT"
                       3 "3=MODERATE EXTENT" 4 "4=LARGE EXTENT"
                       5 "5=VERY LARGE EXTENT" ;
label define LD92AVAI  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY SMALL EXTENT" 2 "2=SMALL EXTENT"
                       3 "3=MODERATE EXTENT" 4 "4=LARGE EXTENT"
                       5 "5=VERY LARGE EXTENT" ;
label define LD94AVAI  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY SMALL EXTENT" 2 "2=SMALL EXTENT"
                       3 "3=MODERATE EXTENT" 4 "4=LARGE EXTENT"
                       5 "5=VERY LARGE EXTENT" ;
label define LD96AVAI  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY SMALL EXTENT" 2 "2=SMALL EXTENT"
                       3 "3=MODERATE EXTENT" 4 "4=LARGE EXTENT"
                       5 "5=VERY LARGE EXTENT" ;
label define LD88BLCH  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY SMALL EXTENT" 2 "2=SMALL EXTENT"
                       3 "3=MODERATE EXTENT" 4 "4=LARGE EXTENT"
                       5 "5=VERY LARGE EXTENT" ;
label define LD90BLCH  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY SMALL EXTENT" 2 "2=SMALL EXTENT"
                       3 "3=MODERATE EXTENT" 4 "4=LARGE EXTENT"
                       5 "5=VERY LARGE EXTENT" ;
label define LD92BLCH  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY SMALL EXTENT" 2 "2=SMALL EXTENT"
                       3 "3=MODERATE EXTENT" 4 "4=LARGE EXTENT"
                       5 "5=VERY LARGE EXTENT" ;
label define LD94BLCH  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY SMALL EXTENT" 2 "2=SMALL EXTENT"
                       3 "3=MODERATE EXTENT" 4 "4=LARGE EXTENT"
                       5 "5=VERY LARGE EXTENT" ;
label define LD96BLCH  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY SMALL EXTENT" 2 "2=SMALL EXTENT"
                       3 "3=MODERATE EXTENT" 4 "4=LARGE EXTENT"
                       5 "5=VERY LARGE EXTENT" ;
label define LDINTYR   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define LDINTSVC  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY SMALL EXTENT" 2 "2=SMALL EXTENT"
                       3 "3=MODERATE EXTENT" 4 "4=LARGE EXTENT"
                       5 "5=VERY LARGE EXTENT" ;
label define LDINTNED  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY SMALL EXTENT" 2 "2=LIMITED EXTENT"
                       3 "3=MODERATE EXTENT" 4 "4=LARGE EXTENT"
                       5 "5=VERY LARGE EXTENT" ;
label define LDINTSRC  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY SMALL EXTENT" 2 "2=SMALL EXTENT"
                       3 "3=MODERATE EXTENT" 4 "4=LARGE EXTENT"
                       5 "5=VERY LARGE EXTENT" ;
label define LDINTTRT  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY SMALL EXTENT" 2 "2=LIMITED EXTENT"
                       3 "3=MODERATE EXTENT" 4 "4=LARGE EXTENT"
                       5 "5=VERY LARGE EXTENT" ;
label define LDINTACC  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=VERY SMALL EXTENT" 2 "2=SMALL EXTENT"
                       3 "3=MODERATE EXTENT" 4 "4=LARGE EXTENT"
                       5 "5=VERY LARGE EXTENT" ;
label define PHARMAVA  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define NEEDLEAV  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define DIABAVA   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define DEALERAV  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define GALLERAV  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define AVAIL     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define AVAIL88   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define AVAIL90   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define AVAIL92   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define AVAIL94   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define AVAIL96   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define PHARMUSE  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define NEEDLUSE  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define DIABUSE   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define DLRUSE    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define GALLERUS  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define USED      -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define USED88    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define USED90    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define USED92    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define USED94    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define USED96    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define NEP       -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define NEP88     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define NEP90     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define NEP92     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define NEP94     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define NEP96     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define INTPRO88  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define INTPRO90  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define INTPRO92  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define INTPRO94  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define INTPRO96  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define RCHD88    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define RCHD90    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define RCHD92    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define RCHD94    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define RCHD96    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define PROGTOT   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define RCHDTOT   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define NORX      -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define DRUGTRTP  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define HIVTESTP  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define STDPROG   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define HIVORPRG  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define OTHORPRG  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define HIVCMPRG  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define OTHCMPRG  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define MEDSVPRG  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define HLPROG    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define OTHINTPR  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define DRUGTRTR  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define HIVTESTR  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define STDRCHD   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define HIVORRCH  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define OTHORRCH  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define HIVCMRCH  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define OTHCMRCH  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define MEDSVRCH  -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define HLRCHD    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define OTHINTR   -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define EARLY     -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE" ;
label define DESIGN    -9 "-9 = SKIP, INELIG, NA" -8 "-8 = REFUSED"
                       -7 "-7 = DO NOT KNOW, UNSURE"
                       -6 "-6 = NOT APPLIC OR REFUSED"
                       -5 "-5 = SYSTEM MISSING" -4 "-4 = INVALID VALUE"
                       1 "1=DESIGN" 2 "2=DEFAULT" 3 "3=BOTH" 4 "4=NEITHER" ;


#delimit cr


/***************************************************************************

 Section 4: Missing Values

 This section will replace numeric missing values (i.e., -9) with generic
 system missing ".".  By default the code in this section is commented out.
 Users wishing to apply the generic missing values should remove the comment
 at the beginning and end of this section.  Note that Stata allows you to
 specify up to 27 unique missing value codes.

****************************************************************/

/*
replace CASEID = . if (CASEID <= -4 )
replace SITECODE = . if (SITECODE <= -4 )
replace SI1 = . if (SI1 <= -4 )
replace SI2 = . if (SI2 <= -4 )
replace SI3 = . if (SI3 <= -4 )
replace SI4 = . if (SI4 <= -4 )
replace SI5 = . if (SI5 <= -4 )
replace SI6_1 = . if (SI6_1 <= -4 )
replace SI6_2 = . if (SI6_2 <= -4 )
replace SI7_1 = . if (SI7_1 <= -4 )
replace SI7_2 = . if (SI7_2 <= -4 )
replace SI7_3 = . if (SI7_3 <= -4 )
replace SI7_4 = . if (SI7_4 <= -4 )
replace SI7_5 = . if (SI7_5 <= -4 )
replace SI8 = . if (SI8 <= -4 )
replace SI9 = . if (SI9 <= -4.0 )
replace SI10_1 = . if (SI10_1 <= -4 )
replace SI10B_2 = . if (SI10B_2 <= -4 )
replace SI11 = . if (SI11 <= -4 )
replace SI12_1 = . if (SI12_1 <= -4 )
replace SI12_2 = . if (SI12_2 <= -4 )
replace SI13 = . if (SI13 <= -4 )
replace SI14 = . if (SI14 <= -4 )
replace SI15 = . if (SI15 <= -4 )
replace SI16 = . if (SI16 <= -4 )
replace SI17 = . if (SI17 <= -4 )
replace SI18 = . if (SI18 <= -4 )
replace SI19 = . if (SI19 <= -4 )
replace SI20 = . if (SI20 <= -4 )
replace SI21 = . if (SI21 <= -4 )
replace SI22_1 = . if (SI22_1 <= -4 )
replace SI22_2 = . if (SI22_2 <= -4 )
replace SI23 = . if (SI23 <= -4 )
replace SI24 = . if (SI24 <= -4 )
replace SI25 = . if (SI25 <= -4 )
replace SI26 = . if (SI26 <= -4 )
replace SI27 = . if (SI27 <= -4 )
replace SI28 = . if (SI28 <= -4 )
replace SI29 = . if (SI29 <= -4 )
replace SI30 = . if (SI30 <= -4 )
replace SI31 = . if (SI31 <= -4 )
replace SI32 = . if (SI32 <= -4 )
replace SI32A = . if (SI32A <= -4 )
replace SI33 = . if (SI33 <= -4 )
replace SI34 = . if (SI34 <= -4 )
replace SI35 = . if (SI35 <= -4 )
replace SI36 = . if (SI36 <= -4 )
replace SI37 = . if (SI37 <= -4 )
replace SI38 = . if (SI38 <= -4 )
replace SI39 = . if (SI39 <= -4 )
replace SI40 = . if (SI40 <= -4 )
replace SI40A = . if (SI40A <= -4 )
replace SI40B = . if (SI40B <= -4 )
replace SI40C = . if (SI40C <= -4 )
replace SI40D = . if (SI40D <= -4 )
replace SI41 = . if (SI41 <= -4 )
replace SI42 = . if (SI42 <= -4 )
replace SI43 = . if (SI43 <= -4 )
replace SI43A = . if (SI43A <= -4 )
replace SI43B = . if (SI43B <= -4 )
replace SI43C = . if (SI43C <= -4 )
replace SI43D = . if (SI43D <= -4 )
replace SI43E = . if (SI43E <= -4 )
replace SI43F = . if (SI43F <= -4 )
replace SI44 = . if (SI44 <= -4 )
replace SI45 = . if (SI45 <= -4 )
replace SI46 = . if (SI46 <= -4 )
replace SI47 = . if (SI47 <= -4 )
replace SI48 = . if (SI48 <= -4 )
replace SI48_1 = . if (SI48_1 <= -4 )
replace SI48_2 = . if (SI48_2 <= -4 )
replace SI49 = . if (SI49 <= -4 )
replace SI49A = . if (SI49A <= -4 )
replace SI49_1 = . if (SI49_1 <= -4 )
replace SI49_2 = . if (SI49_2 <= -4 )
replace SI50 = . if (SI50 <= -4 )
replace SI50A = . if (SI50A <= -4 )
replace SI50A_1 = . if (SI50A_1 <= -4 )
replace SI50A_2 = . if (SI50A_2 <= -4 )
replace SI51_1 = . if (SI51_1 <= -4 )
replace SI51_2 = . if (SI51_2 <= -4 )
replace SI52_1 = . if (SI52_1 <= -4 )
replace SI52_2 = . if (SI52_2 <= -4 )
replace SI54 = . if (SI54 <= -4 )
replace SI55 = . if (SI55 <= -4 )
replace SI55A = . if (SI55A <= -4 )
replace SI55B = . if (SI55B <= -4 )
replace SI55C = . if (SI55C <= -4 )
replace SI55D = . if (SI55D <= -4 )
replace SI56 = . if (SI56 <= -4 )
replace SI57 = . if (SI57 <= -4 )
replace SI58 = . if (SI58 <= -4 )
replace SI59 = . if (SI59 <= -4 )
replace SI60 = . if (SI60 <= -4 )
replace SI61 = . if (SI61 <= -4 )
replace SI62 = . if (SI62 <= -4 )
replace SI62A = . if (SI62A <= -4 )
replace SI62B = . if (SI62B <= -4 )
replace SI62C = . if (SI62C <= -4 )
replace SI62D = . if (SI62D <= -4 )
replace SI63 = . if (SI63 <= -4 )
replace SI64 = . if (SI64 <= -4 )
replace SI65 = . if (SI65 <= -4 )
replace SI65A = . if (SI65A <= -4 )
replace SI66 = . if (SI66 <= -4 )
replace SI67 = . if (SI67 <= -4 )
replace SI68 = . if (SI68 <= -4 )
replace SI68_1 = . if (SI68_1 <= -4 )
replace SI68_2 = . if (SI68_2 <= -4 )
replace SI69 = . if (SI69 <= -4 )
replace SI69A = . if (SI69A <= -4 )
replace SI70 = . if (SI70 <= -4 )
replace SI71 = . if (SI71 <= -4 )
replace SI72_1 = . if (SI72_1 <= -4 )
replace SI72_2 = . if (SI72_2 <= -4 )
replace SI73 = . if (SI73 <= -4 )
replace SI74 = . if (SI74 <= -4 )
replace SI75 = . if (SI75 <= -4 )
replace SI76_1 = . if (SI76_1 <= -4 )
replace SI76_2 = . if (SI76_2 <= -4 )
replace SI77 = . if (SI77 <= -4 )
replace SI78A = . if (SI78A <= -4 )
replace SI78B = . if (SI78B <= -4 )
replace SI78C = . if (SI78C <= -4 )
replace SI78A_1 = . if (SI78A_1 <= -4 )
replace SI78A_2 = . if (SI78A_2 <= -4 )
replace SI78A_3 = . if (SI78A_3 <= -4 )
replace SI79 = . if (SI79 <= -4 )
replace SI80 = . if (SI80 <= -4 )
replace SI81 = . if (SI81 <= -4 )
replace SI82 = . if (SI82 <= -4 )
replace SI83 = . if (SI83 <= -4 )
replace SI84 = . if (SI84 <= -4 )
replace SI85_1 = . if (SI85_1 <= -4 )
replace SI85_2 = . if (SI85_2 <= -4 )
replace SI87 = . if (SI87 <= -4 )
replace SI88 = . if (SI88 <= -4 )
replace SI89 = . if (SI89 <= -4 )
replace SI90 = . if (SI90 <= -4 )
replace SI91 = . if (SI91 <= -4 )
replace SI92 = . if (SI92 <= -4 )
replace SI93 = . if (SI93 <= -4 )
replace SI94 = . if (SI94 <= -4 )
replace SI94A = . if (SI94A <= -4 )
replace SI94B = . if (SI94B <= -4 )
replace SI94C = . if (SI94C <= -4 )
replace SI94D = . if (SI94D <= -4 )
replace SI95 = . if (SI95 <= -4 )
replace SI96 = . if (SI96 <= -4 )
replace SI97 = . if (SI97 <= -4 )
replace SI98 = . if (SI98 <= -4 )
replace SI100 = . if (SI100 <= -4 )
replace SI100A = . if (SI100A <= -4 )
replace SI100B = . if (SI100B <= -4 )
replace SI101 = . if (SI101 <= -4 )
replace SI102 = . if (SI102 <= -4 )
replace SI102B = . if (SI102B <= -4 )
replace SI102C = . if (SI102C <= -4 )
replace SI103 = . if (SI103 <= -4 )
replace SI104 = . if (SI104 <= -4 )
replace SI105 = . if (SI105 <= -4 )
replace SI105A = . if (SI105A <= -4 )
replace SI105B = . if (SI105B <= -4 )
replace SI105C = . if (SI105C <= -4 )
replace SI106 = . if (SI106 <= -4 )
replace SI107 = . if (SI107 <= -4 )
replace SI108 = . if (SI108 <= -4 )
replace SI109 = . if (SI109 <= -4 )
replace SI109A = . if (SI109A <= -4 )
replace SI110 = . if (SI110 <= -4 )
replace SI111 = . if (SI111 <= -4 )
replace SI111A = . if (SI111A <= -4 )
replace SI112 = . if (SI112 <= -4 )
replace SI113_1 = . if (SI113_1 <= -4 )
replace SI113_2 = . if (SI113_2 <= -4 )
replace SI114_1 = . if (SI114_1 <= -4 )
replace SI114_2 = . if (SI114_2 <= -4 )
replace SI115_1 = . if (SI115_1 <= -4 )
replace SI115_2 = . if (SI115_2 <= -4 )
replace SI116 = . if (SI116 <= -4 )
replace SI117 = . if (SI117 <= -4 )
replace SI118 = . if (SI118 <= -4 )
replace SI119 = . if (SI119 <= -4 )
replace SI120 = . if (SI120 <= -4 )
replace SI120A = . if (SI120A <= -4 )
replace SI120B = . if (SI120B <= -4 )
replace SI120C = . if (SI120C <= -4 )
replace SI120D = . if (SI120D <= -4 )
replace SI121 = . if (SI121 <= -4 )
replace SI122 = . if (SI122 <= -4 )
replace SI123 = . if (SI123 <= -4 )
replace SI124 = . if (SI124 <= -4 )
replace SI125 = . if (SI125 <= -4 )
replace SI126 = . if (SI126 <= -4 )
replace SI127 = . if (SI127 <= -4 )
replace SI128 = . if (SI128 <= -4 )
replace SI129_1 = . if (SI129_1 <= -4 )
replace SI129_2 = . if (SI129_2 <= -4 )
replace SI129_3 = . if (SI129_3 <= -4 )
replace SI130 = . if (SI130 <= -4 )
replace SI131 = . if (SI131 <= -4 )
replace SI132 = . if (SI132 <= -4 )
replace SI133 = . if (SI133 <= -4 )
replace SI134_1 = . if (SI134_1 <= -4 )
replace SI134_2 = . if (SI134_2 <= -4 )
replace SI134_3 = . if (SI134_3 <= -4 )
replace SI135 = . if (SI135 <= -4 )
replace SI136 = . if (SI136 <= -4 )
replace SI137 = . if (SI137 <= -4 )
replace SI137A = . if (SI137A <= -4 )
replace SI138 = . if (SI138 <= -4 )
replace SI138A = . if (SI138A <= -4 )
replace SI139 = . if (SI139 <= -4 )
replace SI139A = . if (SI139A <= -4 )
replace SI140 = . if (SI140 <= -4 )
replace SI141 = . if (SI141 <= -4 )
replace SI141A = . if (SI141A <= -4 )
replace SI142 = . if (SI142 <= -4 )
replace SI143 = . if (SI143 <= -4 )
replace SI144 = . if (SI144 <= -4 )
replace SI145 = . if (SI145 <= -4 )
replace SI145A = . if (SI145A <= -4 )
replace SI146 = . if (SI146 <= -4 )
replace SI147A = . if (SI147A <= -4 )
replace SI147B = . if (SI147B <= -4 )
replace SI147C = . if (SI147C <= -4 )
replace SI147A_1 = . if (SI147A_1 <= -4 )
replace SI147A_2 = . if (SI147A_2 <= -4 )
replace SI147A_3 = . if (SI147A_3 <= -4 )
replace SI148 = . if (SI148 <= -4 )
replace SI149 = . if (SI149 <= -4 )
replace SI150 = . if (SI150 <= -4 )
replace SI151_1 = . if (SI151_1 <= -4 )
replace SI151_2 = . if (SI151_2 <= -4 )
replace SI153 = . if (SI153 <= -4 )
replace SI154 = . if (SI154 <= -4 )
replace SI155 = . if (SI155 <= -4 )
replace SI156_1 = . if (SI156_1 <= -4 )
replace SI156_2 = . if (SI156_2 <= -4 )
replace SI156_3 = . if (SI156_3 <= -4 )
replace SI157 = . if (SI157 <= -4 )
replace SI158 = . if (SI158 <= -4 )
replace SI159 = . if (SI159 <= -4 )
replace SI160 = . if (SI160 <= -4 )
replace SI160A = . if (SI160A <= -4 )
replace SI161 = . if (SI161 <= -4 )
replace SI161A = . if (SI161A <= -4 )
replace SI162 = . if (SI162 <= -4 )
replace SI162A = . if (SI162A <= -4 )
replace SI163 = . if (SI163 <= -4 )
replace SI164 = . if (SI164 <= -4 )
replace SI164A = . if (SI164A <= -4 )
replace SI165 = . if (SI165 <= -4 )
replace SI166 = . if (SI166 <= -4 )
replace SI167 = . if (SI167 <= -4 )
replace SI168 = . if (SI168 <= -4 )
replace SI168A = . if (SI168A <= -4 )
replace SI169 = . if (SI169 <= -4 )
replace SI170A = . if (SI170A <= -4 )
replace SI170B = . if (SI170B <= -4 )
replace SI170C = . if (SI170C <= -4 )
replace SI170A_1 = . if (SI170A_1 <= -4 )
replace SI170A_2 = . if (SI170A_2 <= -4 )
replace SI170A_3 = . if (SI170A_3 <= -4 )
replace SI171 = . if (SI171 <= -4 )
replace SI172 = . if (SI172 <= -4 )
replace SI173 = . if (SI173 <= -4 )
replace SI174_1 = . if (SI174_1 <= -4 )
replace SI174_2 = . if (SI174_2 <= -4 )
replace SI176 = . if (SI176 <= -4 )
replace SI177 = . if (SI177 <= -4 )
replace SI177A = . if (SI177A <= -4 )
replace SI178 = . if (SI178 <= -4 )
replace SI178A = . if (SI178A <= -4 )
replace SI179 = . if (SI179 <= -4 )
replace SI180 = . if (SI180 <= -4 )
replace SI180A = . if (SI180A <= -4 )
replace SI181 = . if (SI181 <= -4 )
replace SI182 = . if (SI182 <= -4 )
replace SI182A = . if (SI182A <= -4.0 )
replace SI183 = . if (SI183 <= -4 )
replace SI184 = . if (SI184 <= -4 )
replace SI185 = . if (SI185 <= -4 )
replace SI186 = . if (SI186 <= -4 )
replace SI187 = . if (SI187 <= -4 )
replace SI188 = . if (SI188 <= -4 )
replace SI189 = . if (SI189 <= -4 )
replace SI190 = . if (SI190 <= -4 )
replace SI191 = . if (SI191 <= -4 )
replace SI192_1 = . if (SI192_1 <= -4 )
replace SI192_2 = . if (SI192_2 <= -4 )
replace SI192_3 = . if (SI192_3 <= -4 )
replace SI193 = . if (SI193 <= -4 )
replace SI194 = . if (SI194 <= -4 )
replace SI195 = . if (SI195 <= -4 )
replace SI196 = . if (SI196 <= -4 )
replace SI197 = . if (SI197 <= -4 )
replace SI198 = . if (SI198 <= -4 )
replace SI199 = . if (SI199 <= -4 )
replace SI200_1 = . if (SI200_1 <= -4 )
replace SI200A = . if (SI200A <= -4 )
replace SI201_1 = . if (SI201_1 <= -4 )
replace SI202_1 = . if (SI202_1 <= -4 )
replace SI203_1 = . if (SI203_1 <= -4 )
replace SI204_1 = . if (SI204_1 <= -4 )
replace SI205_1 = . if (SI205_1 <= -4 )
replace SI206_1 = . if (SI206_1 <= -4 )
replace SI208 = . if (SI208 <= -4 )
replace SI209 = . if (SI209 <= -4 )
replace SI210 = . if (SI210 <= -4 )
replace SI211 = . if (SI211 <= -4 )
replace SI212 = . if (SI212 <= -4 )
replace SI213 = . if (SI213 <= -4 )
replace SI215 = . if (SI215 <= -4 )
replace SI216 = . if (SI216 <= -4 )
replace SI217 = . if (SI217 <= -4 )
replace SI217A_1 = . if (SI217A_1 <= -4 )
replace SI217A_2 = . if (SI217A_2 <= -4 )
replace SI217A_3 = . if (SI217A_3 <= -4 )
replace SI217B = . if (SI217B <= -4 )
replace SI218 = . if (SI218 <= -4 )
replace SI218A = . if (SI218A <= -4 )
replace SI218B = . if (SI218B <= -4 )
replace SI218C = . if (SI218C <= -4 )
replace SI218D_1 = . if (SI218D_1 <= -4 )
replace SI218D_2 = . if (SI218D_2 <= -4 )
replace SI218D_3 = . if (SI218D_3 <= -4 )
replace SESADUR = . if (SESADUR <= -4 )
replace SESBDUR = . if (SESBDUR <= -4 )
replace SESAODUR = . if (SESAODUR <= -4 )
replace SESBODUR = . if (SESBODUR <= -4 )
replace OUTDUR = . if (OUTDUR <= -4 )
replace DISTRIB1 = . if (DISTRIB1 <= -4 )
replace DISTINJ = . if (DISTINJ <= -4 )
replace DISTSEX = . if (DISTSEX <= -4 )
replace REHNDLA = . if (REHNDLA <= -4 )
replace REHCNDMA = . if (REHCNDMA <= -4 )
replace REHALLA = . if (REHALLA <= -4 )
replace REHNDLB = . if (REHNDLB <= -4 )
replace REHCNDMB = . if (REHCNDMB <= -4 )
replace REHALLB = . if (REHALLB <= -4 )
replace SIDEMOA = . if (SIDEMOA <= -4 )
replace SIDEMOB = . if (SIDEMOB <= -4 )
replace SIRHSLA = . if (SIRHSLA <= -4 )
replace SIRHSLB = . if (SIRHSLB <= -4 )
replace SIS1 = . if (SIS1 <= -4 )
replace SIS2A = . if (SIS2A <= -4 )
replace SIS2B = . if (SIS2B <= -4 )
replace SIS2C = . if (SIS2C <= -4 )
replace SIS2D = . if (SIS2D <= -4 )
replace SIS3 = . if (SIS3 <= -4 )
replace SIS4 = . if (SIS4 <= -4 )
replace SIS5 = . if (SIS5 <= -4 )
replace SIS6 = . if (SIS6 <= -4 )
replace SIS7 = . if (SIS7 <= -4 )
replace SIS8 = . if (SIS8 <= -4 )
replace SIS9 = . if (SIS9 <= -4 )
replace SIS9A = . if (SIS9A <= -4 )
replace SIS10 = . if (SIS10 <= -4 )
replace SIS11 = . if (SIS11 <= -4 )
replace SIS12 = . if (SIS12 <= -4 )
replace SIS12A = . if (SIS12A <= -4 )
replace SIS13 = . if (SIS13 <= -4 )
replace SIS14 = . if (SIS14 <= -4 )
replace SIS15 = . if (SIS15 <= -4 )
replace SIS16 = . if (SIS16 <= -4 )
replace SIS17 = . if (SIS17 <= -4 )
replace SIS17A = . if (SIS17A <= -4 )
replace SIS18 = . if (SIS18 <= -4 )
replace SIS19 = . if (SIS19 <= -4 )
replace SIS20 = . if (SIS20 <= -4 )
replace SIS21 = . if (SIS21 <= -4 )
replace SIS22 = . if (SIS22 <= -4 )
replace SIS23 = . if (SIS23 <= -4 )
replace SIS24 = . if (SIS24 <= -4 )
replace SIS25 = . if (SIS25 <= -4 )
replace SIS26 = . if (SIS26 <= -4 )
replace SIS27 = . if (SIS27 <= -4 )
replace SIS28 = . if (SIS28 <= -4 )
replace SIS29 = . if (SIS29 <= -4 )
replace SIS30 = . if (SIS30 <= -4 )
replace SIS31 = . if (SIS31 <= -4 )
replace SIS32 = . if (SIS32 <= -4 )
replace SIS33 = . if (SIS33 <= -4 )
replace SIS34 = . if (SIS34 <= -4 )
replace SIS35 = . if (SIS35 <= -4 )
replace SIS36A = . if (SIS36A <= -4 )
replace SIS36B = . if (SIS36B <= -4 )
replace SIS36C = . if (SIS36C <= -4 )
replace SIS37A = . if (SIS37A <= -4 )
replace SIS37B = . if (SIS37B <= -4 )
replace SIS37C = . if (SIS37C <= -4 )
replace SIS38 = . if (SIS38 <= -4 )
replace SIS39 = . if (SIS39 <= -4 )
replace SIS40 = . if (SIS40 <= -4 )
replace SIS41 = . if (SIS41 <= -4 )
replace SIS42 = . if (SIS42 <= -4 )
replace SIS43 = . if (SIS43 <= -4 )
replace SIS43A = . if (SIS43A <= -4 )
replace SIS44 = . if (SIS44 <= -4 )
replace SIS45 = . if (SIS45 <= -4 )
replace SIS46 = . if (SIS46 <= -4 )
replace SIS47 = . if (SIS47 <= -4 )
replace SIS48 = . if (SIS48 <= -4 )
replace SIS49 = . if (SIS49 <= -4 )
replace SIS50 = . if (SIS50 <= -4 )
replace SIS51 = . if (SIS51 <= -4 )
replace SIS52 = . if (SIS52 <= -4 )
replace SIS53 = . if (SIS53 <= -4 )
replace SIS54 = . if (SIS54 <= -4 )
replace SIS55 = . if (SIS55 <= -4 )
replace SIS56 = . if (SIS56 <= -4 )
replace SIS57 = . if (SIS57 <= -4 )
replace SIS58 = . if (SIS58 <= -4 )
replace SIS59 = . if (SIS59 <= -4 )
replace SIS60 = . if (SIS60 <= -4 )
replace SIS61 = . if (SIS61 <= -4 )
replace SIS62A = . if (SIS62A <= -4 )
replace SIS62B = . if (SIS62B <= -4 )
replace SIS62C = . if (SIS62C <= -4 )
replace SIS63A = . if (SIS63A <= -4 )
replace SIS63B = . if (SIS63B <= -4 )
replace SIS63C = . if (SIS63C <= -4 )
replace SIS64 = . if (SIS64 <= -4 )
replace SIS65 = . if (SIS65 <= -4 )
replace SIS66 = . if (SIS66 <= -4 )
replace SIS67 = . if (SIS67 <= -4 )
replace SIS68 = . if (SIS68 <= -4 )
replace SIS69 = . if (SIS69 <= -4 )
replace SIS69A = . if (SIS69A <= -4 )
replace SIS70 = . if (SIS70 <= -4 )
replace SIS71 = . if (SIS71 <= -4 )
replace SIS72 = . if (SIS72 <= -4 )
replace SIS73 = . if (SIS73 <= -4 )
replace SIS74 = . if (SIS74 <= -4 )
replace SIS75 = . if (SIS75 <= -4 )
replace SIS76 = . if (SIS76 <= -4 )
replace SIS77 = . if (SIS77 <= -4 )
replace SIS78 = . if (SIS78 <= -4 )
replace SIS79 = . if (SIS79 <= -4 )
replace SIS80 = . if (SIS80 <= -4 )
replace SIS81 = . if (SIS81 <= -4 )
replace SIS82 = . if (SIS82 <= -4 )
replace SIS83 = . if (SIS83 <= -4 )
replace SIS84 = . if (SIS84 <= -4 )
replace SIS85 = . if (SIS85 <= -4 )
replace SIS86 = . if (SIS86 <= -4 )
replace SIS87 = . if (SIS87 <= -4 )
replace SIS88A = . if (SIS88A <= -4 )
replace SIS88B = . if (SIS88B <= -4 )
replace SIS88C = . if (SIS88C <= -4 )
replace SIS89A = . if (SIS89A <= -4 )
replace SIS89B = . if (SIS89B <= -4 )
replace SIS89C = . if (SIS89C <= -4 )
replace SIS90 = . if (SIS90 <= -4 )
replace SIS91 = . if (SIS91 <= -4 )
replace SIS92 = . if (SIS92 <= -4 )
replace SIS93 = . if (SIS93 <= -4 )
replace SIS94 = . if (SIS94 <= -4 )
replace SIS95 = . if (SIS95 <= -4 )
replace SIS96 = . if (SIS96 <= -4 )
replace SIS97 = . if (SIS97 <= -4 )
replace SIS98 = . if (SIS98 <= -4 )
replace SIS99 = . if (SIS99 <= -4 )
replace SIS100 = . if (SIS100 <= -4 )
replace SIS101 = . if (SIS101 <= -4 )
replace SIS102 = . if (SIS102 <= -4 )
replace SIS103A = . if (SIS103A <= -4 )
replace SIS103B = . if (SIS103B <= -4 )
replace SIS103C = . if (SIS103C <= -4 )
replace SIS106 = . if (SIS106 <= -4 )
replace SIS107 = . if (SIS107 <= -4 )
replace SIS108 = . if (SIS108 <= -4 )
replace SIS109 = . if (SIS109 <= -4 )
replace SIS110 = . if (SIS110 <= -4 )
replace SIS111 = . if (SIS111 <= -4 )
replace SIS112 = . if (SIS112 <= -4 )
replace SIS113 = . if (SIS113 <= -4 )
replace SIS114 = . if (SIS114 <= -4 )
replace SIS115 = . if (SIS115 <= -4 )
replace SIS116 = . if (SIS116 <= -4 )
replace SIS117A = . if (SIS117A <= -4 )
replace SIS117B = . if (SIS117B <= -4 )
replace SIS117C = . if (SIS117C <= -4 )
replace SIS120 = . if (SIS120 <= -4 )
replace SIS121 = . if (SIS121 <= -4 )
replace SIS122 = . if (SIS122 <= -4 )
replace SIS123 = . if (SIS123 <= -4 )
replace SIS124 = . if (SIS124 <= -4 )
replace SIS125 = . if (SIS125 <= -4 )
replace SIS126 = . if (SIS126 <= -4 )
replace SIS127 = . if (SIS127 <= -4 )
replace SIS128 = . if (SIS128 <= -4 )
replace SIS129 = . if (SIS129 <= -4 )
replace SIS130 = . if (SIS130 <= -4 )
replace SIS131A = . if (SIS131A <= -4 )
replace SIS131B = . if (SIS131B <= -4 )
replace SIS131C = . if (SIS131C <= -4 )
replace SIS134 = . if (SIS134 <= -4 )
replace SIS135 = . if (SIS135 <= -4 )
replace SIS136 = . if (SIS136 <= -4 )
replace SIS137 = . if (SIS137 <= -4 )
replace SIS138 = . if (SIS138 <= -4 )
replace SIS139 = . if (SIS139 <= -4 )
replace SIS140 = . if (SIS140 <= -4 )
replace SIS141 = . if (SIS141 <= -4 )
replace SIS142 = . if (SIS142 <= -4 )
replace EINUM = . if (EINUM <= -4 )
replace EI1 = . if (EI1 <= -4 )
replace EI2_1 = . if (EI2_1 <= -4.00 )
replace EI2_2 = . if (EI2_2 <= -4.0 )
replace EI2_3 = . if (EI2_3 <= -4.00 )
replace EI2_4 = . if (EI2_4 <= -4.00 )
replace EI2_5 = . if (EI2_5 <= -4.00 )
replace EI2_6 = . if (EI2_6 <= -4.00 )
replace EI3A_1 = . if (EI3A_1 <= -4 )
replace EI3A_2 = . if (EI3A_2 <= -4 )
replace EI3A_3 = . if (EI3A_3 <= -4 )
replace EI3A_4 = . if (EI3A_4 <= -4 )
replace EI3B = . if (EI3B <= -4 )
replace EI4A_1 = . if (EI4A_1 <= -4 )
replace EI4A_2 = . if (EI4A_2 <= -4 )
replace EI4B_3 = . if (EI4B_3 <= -4 )
replace EI4B_4 = . if (EI4B_4 <= -4 )
replace EI4B_5 = . if (EI4B_5 <= -4 )
replace EI4B_6 = . if (EI4B_6 <= -4 )
replace EI5_1 = . if (EI5_1 <= -4 )
replace EI5_2 = . if (EI5_2 <= -4 )
replace EI6 = . if (EI6 <= -4 )
replace EI7A_1 = . if (EI7A_1 <= -4 )
replace EI7A_2 = . if (EI7A_2 <= -4 )
replace EI7A_3 = . if (EI7A_3 <= -4 )
replace EI7A_4 = . if (EI7A_4 <= -4 )
replace EI7A_5 = . if (EI7A_5 <= -4 )
replace EI7A_6 = . if (EI7A_6 <= -4 )
replace EI7A_7 = . if (EI7A_7 <= -4 )
replace EI7A_8 = . if (EI7A_8 <= -4 )
replace EI7A_9 = . if (EI7A_9 <= -4 )
replace EI7A_10 = . if (EI7A_10 <= -4 )
replace EI7A_11 = . if (EI7A_11 <= -4 )
replace EI7A_12 = . if (EI7A_12 <= -4 )
replace EI7B_1 = . if (EI7B_1 <= -4 )
replace EI7B_2 = . if (EI7B_2 <= -4 )
replace EI7B_3 = . if (EI7B_3 <= -4 )
replace EI7B_4 = . if (EI7B_4 <= -4 )
replace EI7B_5 = . if (EI7B_5 <= -4 )
replace EI7B_6 = . if (EI7B_6 <= -4 )
replace EI7B_7 = . if (EI7B_7 <= -4 )
replace EI7B_8 = . if (EI7B_8 <= -4 )
replace EI7B_9 = . if (EI7B_9 <= -4 )
replace EI7B_10 = . if (EI7B_10 <= -4 )
replace EI8A_1 = . if (EI8A_1 <= -4 )
replace EI8A_2 = . if (EI8A_2 <= -4 )
replace EI8A_3 = . if (EI8A_3 <= -4 )
replace EI8A_4 = . if (EI8A_4 <= -4 )
replace EI8A_5 = . if (EI8A_5 <= -4 )
replace EI8A_6 = . if (EI8A_6 <= -4 )
replace EI8A_7 = . if (EI8A_7 <= -4 )
replace EI8A_8 = . if (EI8A_8 <= -4 )
replace EI8A_9 = . if (EI8A_9 <= -4 )
replace EI8A_10 = . if (EI8A_10 <= -4 )
replace EI8A_11 = . if (EI8A_11 <= -4 )
replace EI8A_12 = . if (EI8A_12 <= -4 )
replace EI8A_13 = . if (EI8A_13 <= -4 )
replace EI8A_14 = . if (EI8A_14 <= -4 )
replace EI8B_1 = . if (EI8B_1 <= -4 )
replace EI8B_2 = . if (EI8B_2 <= -4 )
replace EI8B_3 = . if (EI8B_3 <= -4 )
replace EI8B_4 = . if (EI8B_4 <= -4 )
replace EI9 = . if (EI9 <= -4 )
replace EI10 = . if (EI10 <= -4 )
replace EI11_1 = . if (EI11_1 <= -4 )
replace EI11_2 = . if (EI11_2 <= -4 )
replace EI11_3 = . if (EI11_3 <= -4 )
replace EI11_4 = . if (EI11_4 <= -4 )
replace EI11_5 = . if (EI11_5 <= -4 )
replace EI11_6 = . if (EI11_6 <= -4 )
replace EI11_7 = . if (EI11_7 <= -4 )
replace EI11_8 = . if (EI11_8 <= -4 )
replace EI11_9 = . if (EI11_9 <= -4 )
replace EI11_10 = . if (EI11_10 <= -4 )
replace EI11_11 = . if (EI11_11 <= -4 )
replace EI11_12 = . if (EI11_12 <= -4 )
replace EI11_13 = . if (EI11_13 <= -4 )
replace EI11_14 = . if (EI11_14 <= -4 )
replace EI11_15 = . if (EI11_15 <= -4 )
replace EI12_2 = . if (EI12_2 <= -4 )
replace EI14_1 = . if (EI14_1 <= -4 )
replace EI14_2 = . if (EI14_2 <= -4 )
replace EI14_3 = . if (EI14_3 <= -4 )
replace EI14_4 = . if (EI14_4 <= -4 )
replace EI14_5 = . if (EI14_5 <= -4 )
replace EIDEMO = . if (EIDEMO <= -4 )
replace EIRHSL = . if (EIRHSL <= -4 )
replace EIACTA = . if (EIACTA <= -4 )
replace EIACTB = . if (EIACTB <= -4 )
replace EIDISTA = . if (EIDISTA <= -4 )
replace EIDISTB = . if (EIDISTB <= -4 )
replace EIDUR = . if (EIDUR <= -4 )
replace EIADUR = . if (EIADUR <= -4 )
replace EIBDUR = . if (EIBDUR <= -4 )
replace EIAODUR = . if (EIAODUR <= -4 )
replace EIBODUR = . if (EIBODUR <= -4 )
replace EIIND = . if (EIIND <= -4 )
replace EICOUPLE = . if (EICOUPLE <= -4 )
replace EIGROUP = . if (EIGROUP <= -4 )
replace XDAMC = . if (XDAMC <= -4 )
replace AINTCOU = . if (AINTCOU <= -4 )
replace AINTEDU = . if (AINTEDU <= -4 )
replace AINTBOTH = . if (AINTBOTH <= -4 )
replace AINTOTH = . if (AINTOTH <= -4 )
replace AINTSP = . if (AINTSP <= -4 )
replace AINTAV = . if (AINTAV <= -4 )
replace AAVVIDEO = . if (AAVVIDEO <= -4 )
replace AAVHAND = . if (AAVHAND <= -4 )
replace AAVOTHER = . if (AAVOTHER <= -4 )
replace AAVSP = . if (AAVSP <= -4 )
replace AINTDRUG = . if (AINTDRUG <= -4 )
replace AINTSEX = . if (AINTSEX <= -4 )
replace ABARRIER = . if (ABARRIER <= -4 )
replace ASUPPORT = . if (ASUPPORT <= -4 )
replace ACUES = . if (ACUES <= -4 )
replace ASETGOAL = . if (ASETGOAL <= -4 )
replace AINTPER = . if (AINTPER <= -4 )
replace ATB = . if (ATB <= -4 )
replace AANATOMY = . if (AANATOMY <= -4 )
replace AAPCLIEN = . if (AAPCLIEN <= -4 )
replace ASELFHLP = . if (ASELFHLP <= -4 )
replace ACOMMIT = . if (ACOMMIT <= -4 )
replace ACOMPRTN = . if (ACOMPRTN <= -4 )
replace ACOMPMED = . if (ACOMPMED <= -4 )
replace ALIFPAIN = . if (ALIFPAIN <= -4 )
replace ABLDTRST = . if (ABLDTRST <= -4 )
replace ADISCRIM = . if (ADISCRIM <= -4 )
replace ADOMVIOL = . if (ADOMVIOL <= -4 )
replace AFACACC = . if (AFACACC <= -4 )
replace AFAMISS = . if (AFAMISS <= -4 )
replace AFOODPRP = . if (AFOODPRP <= -4 )
replace AHLTHTX = . if (AHLTHTX <= -4 )
replace AHLTHTOP = . if (AHLTHTOP <= -4 )
replace AHOMELES = . if (AHOMELES <= -4 )
replace APOSAT = . if (APOSAT <= -4 )
replace ALIFPATT = . if (ALIFPATT <= -4 )
replace AMORDEMO = . if (AMORDEMO <= -4 )
replace ANEGSKIL = . if (ANEGSKIL <= -4 )
replace APEERSUP = . if (APEERSUP <= -4 )
replace AROLES = . if (AROLES <= -4 )
replace AREDUBEH = . if (AREDUBEH <= -4 )
replace APOVERTY = . if (APOVERTY <= -4 )
replace APWRLES = . if (APWRLES <= -4 )
replace APROMSLF = . if (APROMSLF <= -4 )
replace ATBTST = . if (ATBTST <= -4 )
replace ADISCST = . if (ADISCST <= -4 )
replace ARESPECT = . if (ARESPECT <= -4 )
replace AROLPLAY = . if (AROLPLAY <= -4 )
replace ASLFEFF = . if (ASLFEFF <= -4 )
replace ASLFENH = . if (ASLFENH <= -4 )
replace ASLFEST = . if (ASLFEST <= -4 )
replace ASKLLTRA = . if (ASKLLTRA <= -4 )
replace ASTRMAN = . if (ASTRMAN <= -4 )
replace ASOCIALS = . if (ASOCIALS <= -4 )
replace APHOTDEM = . if (APHOTDEM <= -4 )
replace ATALID = . if (ATALID <= -4 )
replace ATRUST = . if (ATRUST <= -4 )
replace AETHCUL = . if (AETHCUL <= -4 )
replace AWLLBNG = . if (AWLLBNG <= -4 )
replace AOTH = . if (AOTH <= -4 )
replace AHIV = . if (AHIV <= -4 )
replace AOTHISS = . if (AOTHISS <= -4 )
replace ABOTH = . if (ABOTH <= -4 )
replace AHIVFRST = . if (AHIVFRST <= -4 )
replace AISSFRST = . if (AISSFRST <= -4 )
replace AIND = . if (AIND <= -4 )
replace AGRP = . if (AGRP <= -4 )
replace AGRPSZ = . if (AGRPSZ <= -4 )
replace AGRPCOMP = . if (AGRPCOMP <= -4 )
replace AOTH_ = . if (AOTH_ <= -4 )
replace AOTH_SP = . if (AOTH_SP <= -4 )
replace APROJOFF = . if (APROJOFF <= -4 )
replace ASTREET = . if (ASTREET <= -4 )
replace AVAN = . if (AVAN <= -4 )
replace AOTHPLAC = . if (AOTHPLAC <= -4 )
replace AOTHSPPL = . if (AOTHSPPL <= -4 )
replace APREF_ = . if (APREF_ <= -4 )
replace ASES1 = . if (ASES1 <= -4 )
replace ASES2 = . if (ASES2 <= -4 )
replace ASES3 = . if (ASES3 <= -4 )
replace ASES4 = . if (ASES4 <= -4 )
replace ASES5 = . if (ASES5 <= -4 )
replace ASES6 = . if (ASES6 <= -4 )
replace ANONE = . if (ANONE <= -4 )
replace APHONE = . if (APHONE <= -4 )
replace APHONE_ = . if (APHONE_ <= -4 )
replace AOUTWOR = . if (AOUTWOR <= -4 )
replace AOUTWOR_ = . if (AOUTWOR_ <= -4 )
replace ADROPSES = . if (ADROPSES <= -4 )
replace ADROPSPE = . if (ADROPSPE <= -4 )
replace ASUPGRP = . if (ASUPGRP <= -4 )
replace ALGTHSES = . if (ALGTHSES <= -4 )
replace AOFTNGRP = . if (AOFTNGRP <= -4 )
replace AOTHREIN = . if (AOTHREIN <= -4 )
replace AOTHSP = . if (AOTHSP <= -4 )
replace AINCENT = . if (AINCENT <= -4 )
replace ADESC = . if (ADESC <= -4 )
replace ASTART = . if (ASTART <= -4 )
replace ACOMP = . if (ACOMP <= -4 )
replace ATOT = . if (ATOT <= -4 )
replace ATOTSP = . if (ATOTSP <= -4 )
replace APAID = . if (APAID <= -4 )
replace AGENDER = . if (AGENDER <= -4 )
replace AHEDM = . if (AHEDM <= -4 )
replace AHEDB = . if (AHEDB <= -4 )
replace AHEDN = . if (AHEDN <= -4 )
replace APEERCON = . if (APEERCON <= -4 )
replace ANURSE = . if (ANURSE <= -4 )
replace ADRGCON = . if (ADRGCON <= -4 )
replace AOTHINT = . if (AOTHINT <= -4 )
replace AOTHSPIN = . if (AOTHSPIN <= -4 )
replace ATRANSP = . if (ATRANSP <= -4 )
replace AHIVTEST = . if (AHIVTEST <= -4 )
replace AHIVCOUN = . if (AHIVCOUN <= -4 )
replace AURINTST = . if (AURINTST <= -4 )
replace AOTHIS2 = . if (AOTHIS2 <= -4 )
replace AOTHIS1 = . if (AOTHIS1 <= -4 )
replace AOTHIS3 = . if (AOTHIS3 <= -4 )
replace AINDSZ = . if (AINDSZ <= -4 )
replace AINDCOMP = . if (AINDCOMP <= -4 )
replace LD88HIVP = . if (LD88HIVP <= -4.000 )
replace LD90HIVP = . if (LD90HIVP <= -4.000 )
replace LD92HIVP = . if (LD92HIVP <= -4.00 )
replace LD94HIVP = . if (LD94HIVP <= -4.00 )
replace LD96HIVP = . if (LD96HIVP <= -4.00 )
replace LD88ACCP = . if (LD88ACCP <= -4 )
replace LD90ACCP = . if (LD90ACCP <= -4 )
replace LD92ACCP = . if (LD92ACCP <= -4 )
replace LD94ACCP = . if (LD94ACCP <= -4 )
replace LD96ACCP = . if (LD96ACCP <= -4 )
replace LD88HIVI = . if (LD88HIVI <= -4.000 )
replace LD90HIVI = . if (LD90HIVI <= -4.000 )
replace LD92HIVI = . if (LD92HIVI <= -4.000 )
replace LD94HIVI = . if (LD94HIVI <= -4.000 )
replace LD96HIVI = . if (LD96HIVI <= -4.000 )
replace LD88ACCI = . if (LD88ACCI <= -4 )
replace LD90ACCI = . if (LD90ACCI <= -4 )
replace LD92ACCI = . if (LD92ACCI <= -4 )
replace LD94ACCI = . if (LD94ACCI <= -4 )
replace LD96ACCI = . if (LD96ACCI <= -4 )
replace LD88PHAV = . if (LD88PHAV <= -4 )
replace LD90PHAV = . if (LD90PHAV <= -4 )
replace LD92PHAV = . if (LD92PHAV <= -4 )
replace LD94PHAV = . if (LD94PHAV <= -4 )
replace LD96PHAV = . if (LD96PHAV <= -4 )
replace LD88PHUS = . if (LD88PHUS <= -4 )
replace LD90PHUS = . if (LD90PHUS <= -4 )
replace LD92PHUS = . if (LD92PHUS <= -4 )
replace LD94PHUS = . if (LD94PHUS <= -4 )
replace LD96PHUS = . if (LD96PHUS <= -4 )
replace LD88PHAC = . if (LD88PHAC <= -4 )
replace LD90PHAC = . if (LD90PHAC <= -4 )
replace LD92PHAC = . if (LD92PHAC <= -4 )
replace LD94PHAC = . if (LD94PHAC <= -4 )
replace LD96PHAC = . if (LD96PHAC <= -4 )
replace LD88NEAV = . if (LD88NEAV <= -4 )
replace LD90NEAV = . if (LD90NEAV <= -4 )
replace LD92NEAV = . if (LD92NEAV <= -4 )
replace LD94NEAV = . if (LD94NEAV <= -4 )
replace LD96NEAV = . if (LD96NEAV <= -4 )
replace LD88NEUS = . if (LD88NEUS <= -4 )
replace LD90NEUS = . if (LD90NEUS <= -4 )
replace LD92NEUS = . if (LD92NEUS <= -4 )
replace LD94NEUS = . if (LD94NEUS <= -4 )
replace LD96NEUS = . if (LD96NEUS <= -4 )
replace LD88NEAC = . if (LD88NEAC <= -4 )
replace LD90NEAC = . if (LD90NEAC <= -4 )
replace LD92NEAC = . if (LD92NEAC <= -4 )
replace LD94NEAC = . if (LD94NEAC <= -4 )
replace LD96NEAC = . if (LD96NEAC <= -4 )
replace LD88DBAV = . if (LD88DBAV <= -4 )
replace LD90DBAV = . if (LD90DBAV <= -4 )
replace LD92DBAV = . if (LD92DBAV <= -4 )
replace LD94DBAV = . if (LD94DBAV <= -4 )
replace LD96DBAV = . if (LD96DBAV <= -4 )
replace LD88DBUS = . if (LD88DBUS <= -4 )
replace LD90DBUS = . if (LD90DBUS <= -4 )
replace LD92DBUS = . if (LD92DBUS <= -4 )
replace LD94DBUS = . if (LD94DBUS <= -4 )
replace LD96DBUS = . if (LD96DBUS <= -4 )
replace LD88DBAC = . if (LD88DBAC <= -4 )
replace LD90DBAC = . if (LD90DBAC <= -4 )
replace LD92DBAC = . if (LD92DBAC <= -4 )
replace LD94DBAC = . if (LD94DBAC <= -4 )
replace LD96DBAC = . if (LD96DBAC <= -4 )
replace LD88SDAV = . if (LD88SDAV <= -4 )
replace LD90SDAV = . if (LD90SDAV <= -4 )
replace LD92SDAV = . if (LD92SDAV <= -4 )
replace LD94SDAV = . if (LD94SDAV <= -4 )
replace LD96SDAV = . if (LD96SDAV <= -4 )
replace LD88SDUS = . if (LD88SDUS <= -4 )
replace LD90SDUS = . if (LD90SDUS <= -4 )
replace LD92SDUS = . if (LD92SDUS <= -4 )
replace LD94SDUS = . if (LD94SDUS <= -4 )
replace LD96SDUS = . if (LD96SDUS <= -4 )
replace LD88SDAC = . if (LD88SDAC <= -4 )
replace LD90SDAC = . if (LD90SDAC <= -4 )
replace LD92SDAC = . if (LD92SDAC <= -4 )
replace LD94SDAC = . if (LD94SDAC <= -4 )
replace LD96SDAC = . if (LD96SDAC <= -4 )
replace LD88SGAV = . if (LD88SGAV <= -4 )
replace LD90SGAV = . if (LD90SGAV <= -4 )
replace LD92SGAV = . if (LD92SGAV <= -4 )
replace LD94SGAV = . if (LD94SGAV <= -4 )
replace LD96SGAV = . if (LD96SGAV <= -4 )
replace LD88SGUS = . if (LD88SGUS <= -4 )
replace LD90SGUS = . if (LD90SGUS <= -4 )
replace LD92SGUS = . if (LD92SGUS <= -4 )
replace LD94SGUS = . if (LD94SGUS <= -4 )
replace LD96SGUS = . if (LD96SGUS <= -4 )
replace LD88SGAC = . if (LD88SGAC <= -4 )
replace LD90SGAC = . if (LD90SGAC <= -4 )
replace LD92SGAC = . if (LD92SGAC <= -4 )
replace LD94SGAC = . if (LD94SGAC <= -4 )
replace LD96SGAC = . if (LD96SGAC <= -4 )
replace LD88NE01 = . if (LD88NE01 <= -4 )
replace LD90NE01 = . if (LD90NE01 <= -4 )
replace LD92NE01 = . if (LD92NE01 <= -4 )
replace LD94NE01 = . if (LD94NE01 <= -4 )
replace LD96NE01 = . if (LD96NE01 <= -4 )
replace LD88NE02 = . if (LD88NE02 <= -4 )
replace LD90NE02 = . if (LD90NE02 <= -4 )
replace LD92NE02 = . if (LD92NE02 <= -4 )
replace LD94NE02 = . if (LD94NE02 <= -4 )
replace LD96NE02 = . if (LD96NE02 <= -4 )
replace LD88NE03 = . if (LD88NE03 <= -4 )
replace LD90NE03 = . if (LD90NE03 <= -4 )
replace LD92NE03 = . if (LD92NE03 <= -4 )
replace LD94NE03 = . if (LD94NE03 <= -4 )
replace LD96NE03 = . if (LD96NE03 <= -4 )
replace LD88NEC1 = . if (LD88NEC1 <= -4 )
replace LD90NEC1 = . if (LD90NEC1 <= -4 )
replace LD92NEC1 = . if (LD92NEC1 <= -4 )
replace LD94NEC1 = . if (LD94NEC1 <= -4 )
replace LD96NEC1 = . if (LD96NEC1 <= -4 )
replace LD88NEC2 = . if (LD88NEC2 <= -4 )
replace LD90NEC2 = . if (LD90NEC2 <= -4 )
replace LD92NEC2 = . if (LD92NEC2 <= -4 )
replace LD94NEC2 = . if (LD94NEC2 <= -4 )
replace LD96NEC2 = . if (LD96NEC2 <= -4 )
replace LD90OP1 = . if (LD90OP1 <= -4 )
replace LD92OP1 = . if (LD92OP1 <= -4 )
replace LD94OP1 = . if (LD94OP1 <= -4 )
replace LD96OP1 = . if (LD96OP1 <= -4 )
replace LD92OP2 = . if (LD92OP2 <= -4 )
replace LD94OP2 = . if (LD94OP2 <= -4 )
replace LD96OP2 = . if (LD96OP2 <= -4 )
replace LD94OP3 = . if (LD94OP3 <= -4 )
replace LD96OP3 = . if (LD96OP3 <= -4 )
replace LD90MAX1 = . if (LD90MAX1 <= -4 )
replace LD92MAX1 = . if (LD92MAX1 <= -4 )
replace LD94MAX1 = . if (LD94MAX1 <= -4 )
replace LD96MAX1 = . if (LD96MAX1 <= -4 )
replace LD94MAX2 = . if (LD94MAX2 <= -4 )
replace LD96MAX2 = . if (LD96MAX2 <= -4 )
replace LD94MAX3 = . if (LD94MAX3 <= -4 )
replace LD96MAX3 = . if (LD96MAX3 <= -4 )
replace LD90ANN1 = . if (LD90ANN1 <= -4 )
replace LD92ANN1 = . if (LD92ANN1 <= -4 )
replace LD94ANN1 = . if (LD94ANN1 <= -4 )
replace LD96ANN1 = . if (LD96ANN1 <= -4 )
replace LD96ANN2 = . if (LD96ANN2 <= -4 )
replace LD88LAWS = . if (LD88LAWS <= -4 )
replace LD90LAWS = . if (LD90LAWS <= -4 )
replace LD92LAWS = . if (LD92LAWS <= -4 )
replace LD94LAWS = . if (LD94LAWS <= -4 )
replace LD96LAWS = . if (LD96LAWS <= -4 )
replace LD88LAWL = . if (LD88LAWL <= -4 )
replace LD90LAWL = . if (LD90LAWL <= -4 )
replace LD92LAWL = . if (LD92LAWL <= -4 )
replace LD94LAWL = . if (LD94LAWL <= -4 )
replace LD96LAWL = . if (LD96LAWL <= -4 )
replace LD88NORX = . if (LD88NORX <= -4 )
replace LD90NORX = . if (LD90NORX <= -4 )
replace LD92NORX = . if (LD92NORX <= -4 )
replace LD94NORX = . if (LD94NORX <= -4 )
replace LD96NORX = . if (LD96NORX <= -4 )
replace LD88MINP = . if (LD88MINP <= -4 )
replace LD90MINP = . if (LD90MINP <= -4 )
replace LD92MINP = . if (LD92MINP <= -4 )
replace LD94MINP = . if (LD94MINP <= -4 )
replace LD96MINP = . if (LD96MINP <= -4 )
replace LD88ID = . if (LD88ID <= -4 )
replace LD90ID = . if (LD90ID <= -4 )
replace LD92ID = . if (LD92ID <= -4 )
replace LD94ID = . if (LD94ID <= -4 )
replace LD96ID = . if (LD96ID <= -4 )
replace LD88SIG = . if (LD88SIG <= -4 )
replace LD90SIG = . if (LD90SIG <= -4 )
replace LD92SIG = . if (LD92SIG <= -4 )
replace LD94SIG = . if (LD94SIG <= -4 )
replace LD96SIG = . if (LD96SIG <= -4 )
replace LD88PRDB = . if (LD88PRDB <= -4 )
replace LD90PRDB = . if (LD90PRDB <= -4 )
replace LD92PRDB = . if (LD92PRDB <= -4 )
replace LD94PRDB = . if (LD94PRDB <= -4 )
replace LD96PRDB = . if (LD96PRDB <= -4 )
replace LD88DTPP = . if (LD88DTPP <= -4 )
replace LD90DTPP = . if (LD90DTPP <= -4 )
replace LD92DTPP = . if (LD92DTPP <= -4 )
replace LD94DTPP = . if (LD94DTPP <= -4 )
replace LD96DTPP = . if (LD96DTPP <= -4 )
replace LD88DTPR = . if (LD88DTPR <= -4 )
replace LD90DTPR = . if (LD90DTPR <= -4 )
replace LD92DTPR = . if (LD92DTPR <= -4 )
replace LD94DTPR = . if (LD94DTPR <= -4 )
replace LD96DTPR = . if (LD96DTPR <= -4 )
replace LD88HTCP = . if (LD88HTCP <= -4 )
replace LD90HTCP = . if (LD90HTCP <= -4 )
replace LD92HTCP = . if (LD92HTCP <= -4 )
replace LD94HTCP = . if (LD94HTCP <= -4 )
replace LD96HTCP = . if (LD96HTCP <= -4 )
replace LD88HTCR = . if (LD88HTCR <= -4 )
replace LD90HTCR = . if (LD90HTCR <= -4 )
replace LD92HTCR = . if (LD92HTCR <= -4 )
replace LD94HTCR = . if (LD94HTCR <= -4 )
replace LD96HTCR = . if (LD96HTCR <= -4 )
replace LD88STDP = . if (LD88STDP <= -4 )
replace LD90STDP = . if (LD90STDP <= -4 )
replace LD92STDP = . if (LD92STDP <= -4 )
replace LD94STDP = . if (LD94STDP <= -4 )
replace LD96STDP = . if (LD96STDP <= -4 )
replace LD88STDR = . if (LD88STDR <= -4 )
replace LD90STDR = . if (LD90STDR <= -4 )
replace LD92STDR = . if (LD92STDR <= -4 )
replace LD94STDR = . if (LD94STDR <= -4 )
replace LD96STDR = . if (LD96STDR <= -4 )
replace LD88HOPP = . if (LD88HOPP <= -4 )
replace LD90HOPP = . if (LD90HOPP <= -4 )
replace LD92HOPP = . if (LD92HOPP <= -4 )
replace LD94HOPP = . if (LD94HOPP <= -4 )
replace LD96HOPP = . if (LD96HOPP <= -4 )
replace LD88HOPR = . if (LD88HOPR <= -4 )
replace LD90HOPR = . if (LD90HOPR <= -4 )
replace LD92HOPR = . if (LD92HOPR <= -4 )
replace LD94HOPR = . if (LD94HOPR <= -4 )
replace LD96HOPR = . if (LD96HOPR <= -4 )
replace LD88OOPP = . if (LD88OOPP <= -4 )
replace LD90OOPP = . if (LD90OOPP <= -4 )
replace LD92OOPP = . if (LD92OOPP <= -4 )
replace LD94OOPP = . if (LD94OOPP <= -4 )
replace LD96OOPP = . if (LD96OOPP <= -4 )
replace LD88OOPR = . if (LD88OOPR <= -4 )
replace LD90OOPR = . if (LD90OOPR <= -4 )
replace LD92OOPR = . if (LD92OOPR <= -4 )
replace LD94OOPR = . if (LD94OOPR <= -4 )
replace LD96OOPR = . if (LD96OOPR <= -4 )
replace LD88HCMP = . if (LD88HCMP <= -4 )
replace LD90HCMP = . if (LD90HCMP <= -4 )
replace LD92HCMP = . if (LD92HCMP <= -4 )
replace LD94HCMP = . if (LD94HCMP <= -4 )
replace LD96HCMP = . if (LD96HCMP <= -4 )
replace LD88HCMR = . if (LD88HCMR <= -4 )
replace LD90HCMR = . if (LD90HCMR <= -4 )
replace LD92HCMR = . if (LD92HCMR <= -4 )
replace LD94HCMR = . if (LD94HCMR <= -4 )
replace LD96HCMR = . if (LD96HCMR <= -4 )
replace LD88OCMP = . if (LD88OCMP <= -4 )
replace LD90OCMP = . if (LD90OCMP <= -4 )
replace LD92OCMP = . if (LD92OCMP <= -4 )
replace LD94OCMP = . if (LD94OCMP <= -4 )
replace LD96OCMP = . if (LD96OCMP <= -4 )
replace LD88OCMR = . if (LD88OCMR <= -4 )
replace LD90OCMR = . if (LD90OCMR <= -4 )
replace LD92OCMR = . if (LD92OCMR <= -4 )
replace LD94OCMR = . if (LD94OCMR <= -4 )
replace LD96OCMR = . if (LD96OCMR <= -4 )
replace LD88MSP = . if (LD88MSP <= -4 )
replace LD90MSP = . if (LD90MSP <= -4 )
replace LD92MSP = . if (LD92MSP <= -4 )
replace LD94MSP = . if (LD94MSP <= -4 )
replace LD96MSP = . if (LD96MSP <= -4 )
replace LD88MSR = . if (LD88MSR <= -4 )
replace LD90MSR = . if (LD90MSR <= -4 )
replace LD92MSR = . if (LD92MSR <= -4 )
replace LD94MSR = . if (LD94MSR <= -4 )
replace LD96MSR = . if (LD96MSR <= -4 )
replace LD88HLP = . if (LD88HLP <= -4 )
replace LD90HLP = . if (LD90HLP <= -4 )
replace LD92HLP = . if (LD92HLP <= -4 )
replace LD94HLP = . if (LD94HLP <= -4 )
replace LD96HLP = . if (LD96HLP <= -4 )
replace LD88HLR = . if (LD88HLR <= -4 )
replace LD90HLR = . if (LD90HLR <= -4 )
replace LD92HLR = . if (LD92HLR <= -4 )
replace LD94HLR = . if (LD94HLR <= -4 )
replace LD96HLR = . if (LD96HLR <= -4 )
replace LD88OIPP = . if (LD88OIPP <= -4 )
replace LD90OIPP = . if (LD90OIPP <= -4 )
replace LD92OIPP = . if (LD92OIPP <= -4 )
replace LD94OIPP = . if (LD94OIPP <= -4 )
replace LD96OIPP = . if (LD96OIPP <= -4 )
replace LD88OIPR = . if (LD88OIPR <= -4 )
replace LD90OIPR = . if (LD90OIPR <= -4 )
replace LD92OIPR = . if (LD92OIPR <= -4 )
replace LD94OIPR = . if (LD94OIPR <= -4 )
replace LD96OIPR = . if (LD96OIPR <= -4 )
replace LDPOPEST = . if (LDPOPEST <= -4 )
replace LD88IDU = . if (LD88IDU <= -4 )
replace LD88CONF = . if (LD88CONF <= -4 )
replace LD88GEO = . if (LD88GEO <= -4 )
replace LD88TRAN = . if (LD88TRAN <= -4 )
replace LD88IMM = . if (LD88IMM <= -4 )
replace LD88EMI = . if (LD88EMI <= -4 )
replace LD90IDU = . if (LD90IDU <= -4 )
replace LD90CONF = . if (LD90CONF <= -4 )
replace LD90GEO = . if (LD90GEO <= -4 )
replace LD90TRAN = . if (LD90TRAN <= -4 )
replace LD90IMM = . if (LD90IMM <= -4 )
replace LD90EMI = . if (LD90EMI <= -4 )
replace LD92IDU = . if (LD92IDU <= -4 )
replace LD92CONF = . if (LD92CONF <= -4 )
replace LD92GEO = . if (LD92GEO <= -4 )
replace LD92TRAN = . if (LD92TRAN <= -4 )
replace LD92IMM = . if (LD92IMM <= -4 )
replace LD92EMI = . if (LD92EMI <= -4 )
replace LD94IDU = . if (LD94IDU <= -4 )
replace LD94CONF = . if (LD94CONF <= -4 )
replace LD94GEO = . if (LD94GEO <= -4 )
replace LD94TRAN = . if (LD94TRAN <= -4 )
replace LD94IMM = . if (LD94IMM <= -4 )
replace LD94EMI = . if (LD94EMI <= -4 )
replace LD96IDU = . if (LD96IDU <= -4 )
replace LD96CONF = . if (LD96CONF <= -4 )
replace LD96GEO = . if (LD96GEO <= -4 )
replace LD96TRAN = . if (LD96TRAN <= -4 )
replace LD96IMM = . if (LD96IMM <= -4 )
replace LD96EMI = . if (LD96EMI <= -4 )
replace LD88HL = . if (LD88HL <= -4 )
replace LD88JAIL = . if (LD88JAIL <= -4 )
replace LD88TRNS = . if (LD88TRNS <= -4 )
replace LD88INST = . if (LD88INST <= -4 )
replace LD90HL = . if (LD90HL <= -4 )
replace LD90JAIL = . if (LD90JAIL <= -4 )
replace LD90TRNS = . if (LD90TRNS <= -4 )
replace LD90INST = . if (LD90INST <= -4 )
replace LD92HL = . if (LD92HL <= -4 )
replace LD92JAIL = . if (LD92JAIL <= -4 )
replace LD92TRNS = . if (LD92TRNS <= -4 )
replace LD92INST = . if (LD92INST <= -4 )
replace LD94HL = . if (LD94HL <= -4 )
replace LD94JAIL = . if (LD94JAIL <= -4 )
replace LD94TRNS = . if (LD94TRNS <= -4 )
replace LD94INST = . if (LD94INST <= -4 )
replace LD96HL = . if (LD96HL <= -4 )
replace LD96JAIL = . if (LD96JAIL <= -4 )
replace LD96TRNS = . if (LD96TRNS <= -4 )
replace LD96INST = . if (LD96INST <= -4 )
replace LD88MALE = . if (LD88MALE <= -4 )
replace LD90MALE = . if (LD90MALE <= -4 )
replace LD92MALE = . if (LD92MALE <= -4 )
replace LD94MALE = . if (LD94MALE <= -4 )
replace LD96MALE = . if (LD96MALE <= -4 )
replace LD88FEM = . if (LD88FEM <= -4 )
replace LD90FEM = . if (LD90FEM <= -4 )
replace LD92FEM = . if (LD92FEM <= -4 )
replace LD94FEM = . if (LD94FEM <= -4 )
replace LD96FEM = . if (LD96FEM <= -4 )
replace LD88U25 = . if (LD88U25 <= -4 )
replace LD90U25 = . if (LD90U25 <= -4 )
replace LD92U25 = . if (LD92U25 <= -4 )
replace LD94U25 = . if (LD94U25 <= -4 )
replace LD96U25 = . if (LD96U25 <= -4 )
replace LD882535 = . if (LD882535 <= -4 )
replace LD902535 = . if (LD902535 <= -4 )
replace LD922535 = . if (LD922535 <= -4 )
replace LD942535 = . if (LD942535 <= -4 )
replace LD962535 = . if (LD962535 <= -4 )
replace LD88G35 = . if (LD88G35 <= -4 )
replace LD90G35 = . if (LD90G35 <= -4 )
replace LD92G35 = . if (LD92G35 <= -4 )
replace LD94G35 = . if (LD94G35 <= -4 )
replace LD96G35 = . if (LD96G35 <= -4 )
replace LD88BLA = . if (LD88BLA <= -4 )
replace LD90BLA = . if (LD90BLA <= -4 )
replace LD92BLA = . if (LD92BLA <= -4 )
replace LD94BLA = . if (LD94BLA <= -4 )
replace LD96BLA = . if (LD96BLA <= -4 )
replace LD88WHIT = . if (LD88WHIT <= -4 )
replace LD90WHIT = . if (LD90WHIT <= -4 )
replace LD92WHIT = . if (LD92WHIT <= -4 )
replace LD94WHIT = . if (LD94WHIT <= -4 )
replace LD96WHIT = . if (LD96WHIT <= -4 )
replace LD88HISP = . if (LD88HISP <= -4 )
replace LD90HISP = . if (LD90HISP <= -4 )
replace LD92HISP = . if (LD92HISP <= -4 )
replace LD94HISP = . if (LD94HISP <= -4 )
replace LD96HISP = . if (LD96HISP <= -4 )
replace LD88OTHR = . if (LD88OTHR <= -4 )
replace LD90OTHR = . if (LD90OTHR <= -4 )
replace LD92OTHR = . if (LD92OTHR <= -4 )
replace LD94OTHR = . if (LD94OTHR <= -4 )
replace LD96OTHR = . if (LD96OTHR <= -4 )
replace LD88OTH = . if (LD88OTH <= -4 )
replace LD90OTH = . if (LD90OTH <= -4 )
replace LD92OTH = . if (LD92OTH <= -4 )
replace LD94OTH = . if (LD94OTH <= -4 )
replace LD96OTH = . if (LD96OTH <= -4 )
replace LD88HER = . if (LD88HER <= -4 )
replace LD90HER = . if (LD90HER <= -4.0 )
replace LD92HER = . if (LD92HER <= -4.0 )
replace LD94HER = . if (LD94HER <= -4.0 )
replace LD96HER = . if (LD96HER <= -4.0 )
replace LD88COC = . if (LD88COC <= -4 )
replace LD90COC = . if (LD90COC <= -4.0 )
replace LD92COC = . if (LD92COC <= -4.0 )
replace LD94COC = . if (LD94COC <= -4.0 )
replace LD96COC = . if (LD96COC <= -4.0 )
replace LD88SPED = . if (LD88SPED <= -4 )
replace LD90SPED = . if (LD90SPED <= -4.0 )
replace LD92SPED = . if (LD92SPED <= -4.0 )
replace LD94SPED = . if (LD94SPED <= -4.0 )
replace LD96SPED = . if (LD96SPED <= -4.0 )
replace LD88METH = . if (LD88METH <= -4 )
replace LD90METH = . if (LD90METH <= -4 )
replace LD92METH = . if (LD92METH <= -4 )
replace LD94METH = . if (LD94METH <= -4.0 )
replace LD96METH = . if (LD96METH <= -4 )
replace LD88OTDR = . if (LD88OTDR <= -4 )
replace LD90OTDR = . if (LD90OTDR <= -4 )
replace LD92OTDR = . if (LD92OTDR <= -4 )
replace LD94OTDR = . if (LD94OTDR <= -4 )
replace LD96OTDR = . if (LD96OTDR <= -4 )
replace LD88CON1 = . if (LD88CON1 <= -4 )
replace LD90CON1 = . if (LD90CON1 <= -4 )
replace LD92CON1 = . if (LD92CON1 <= -4 )
replace LD94CON1 = . if (LD94CON1 <= -4 )
replace LD96CON1 = . if (LD96CON1 <= -4 )
replace LD88HERA = . if (LD88HERA <= -4 )
replace LD90HERA = . if (LD90HERA <= -4 )
replace LD92HERA = . if (LD92HERA <= -4 )
replace LD94HERA = . if (LD94HERA <= -4 )
replace LD96HERA = . if (LD96HERA <= -4 )
replace LD88COCA = . if (LD88COCA <= -4 )
replace LD90COCA = . if (LD90COCA <= -4 )
replace LD92COCA = . if (LD92COCA <= -4 )
replace LD94COCA = . if (LD94COCA <= -4 )
replace LD96COCA = . if (LD96COCA <= -4 )
replace LD88SPDA = . if (LD88SPDA <= -4 )
replace LD90SPDA = . if (LD90SPDA <= -4 )
replace LD92SPDA = . if (LD92SPDA <= -4 )
replace LD94SPDA = . if (LD94SPDA <= -4 )
replace LD96SPDA = . if (LD96SPDA <= -4 )
replace LD88META = . if (LD88META <= -4 )
replace LD90META = . if (LD90META <= -4 )
replace LD92META = . if (LD92META <= -4 )
replace LD94META = . if (LD94META <= -4 )
replace LD96META = . if (LD96META <= -4 )
replace LD88OTHA = . if (LD88OTHA <= -4 )
replace LD90OTHA = . if (LD90OTHA <= -4 )
replace LD92OTHA = . if (LD92OTHA <= -4 )
replace LD94OTHA = . if (LD94OTHA <= -4 )
replace LD96OTHA = . if (LD96OTHA <= -4 )
replace LD88HERP = . if (LD88HERP <= -4 )
replace LD90HERP = . if (LD90HERP <= -4 )
replace LD92HERP = . if (LD92HERP <= -4 )
replace LD94HERP = . if (LD94HERP <= -4 )
replace LD96HERP = . if (LD96HERP <= -4 )
replace LD88COCP = . if (LD88COCP <= -4 )
replace LD90COCP = . if (LD90COCP <= -4 )
replace LD92COCP = . if (LD92COCP <= -4 )
replace LD94COCP = . if (LD94COCP <= -4 )
replace LD96COCP = . if (LD96COCP <= -4 )
replace LD88SPDP = . if (LD88SPDP <= -4 )
replace LD90SPDP = . if (LD90SPDP <= -4 )
replace LD92SPDP = . if (LD92SPDP <= -4 )
replace LD94SPDP = . if (LD94SPDP <= -4 )
replace LD96SPDP = . if (LD96SPDP <= -4 )
replace LD88METP = . if (LD88METP <= -4 )
replace LD90METP = . if (LD90METP <= -4 )
replace LD92METP = . if (LD92METP <= -4 )
replace LD94METP = . if (LD94METP <= -4 )
replace LD96METP = . if (LD96METP <= -4 )
replace LD88OTHP = . if (LD88OTHP <= -4 )
replace LD90OTHP = . if (LD90OTHP <= -4 )
replace LD92OTHP = . if (LD92OTHP <= -4 )
replace LD94OTHP = . if (LD94OTHP <= -4 )
replace LD96OTHP = . if (LD96OTHP <= -4 )
replace LD88POP = . if (LD88POP <= -4 )
replace LD90POP = . if (LD90POP <= -4.0 )
replace LD92POP = . if (LD92POP <= -4.0 )
replace LD94POP = . if (LD94POP <= -4.0 )
replace LD96POP = . if (LD96POP <= -4.0 )
replace LD88CON2 = . if (LD88CON2 <= -4 )
replace LD90CON2 = . if (LD90CON2 <= -4 )
replace LD92CON2 = . if (LD92CON2 <= -4 )
replace LD94CON2 = . if (LD94CON2 <= -4 )
replace LD96CON2 = . if (LD96CON2 <= -4 )
replace LD88GAL = . if (LD88GAL <= -4 )
replace LD90GAL = . if (LD90GAL <= -4 )
replace LD92GAL = . if (LD92GAL <= -4 )
replace LD94GAL = . if (LD94GAL <= -4 )
replace LD96GAL = . if (LD96GAL <= -4 )
replace LD88NGAL = . if (LD88NGAL <= -4 )
replace LD90NGAL = . if (LD90NGAL <= -4 )
replace LD92NGAL = . if (LD92NGAL <= -4 )
replace LD94NGAL = . if (LD94NGAL <= -4 )
replace LD96NGAL = . if (LD96NGAL <= -4 )
replace LD88DISP = . if (LD88DISP <= -4 )
replace LD90DISP = . if (LD90DISP <= -4 )
replace LD92DISP = . if (LD92DISP <= -4 )
replace LD94DISP = . if (LD94DISP <= -4 )
replace LD96DISP = . if (LD96DISP <= -4 )
replace LD88HAR = . if (LD88HAR <= -4 )
replace LD90HAR = . if (LD90HAR <= -4 )
replace LD92HAR = . if (LD92HAR <= -4 )
replace LD94HAR = . if (LD94HAR <= -4 )
replace LD96HAR = . if (LD96HAR <= -4 )
replace LD88INIT = . if (LD88INIT <= -4 )
replace LD90INIT = . if (LD90INIT <= -4 )
replace LD92INIT = . if (LD92INIT <= -4 )
replace LD94INIT = . if (LD94INIT <= -4 )
replace LD96INIT = . if (LD96INIT <= -4 )
replace LD88NINI = . if (LD88NINI <= -4 )
replace LD90NINI = . if (LD90NINI <= -4 )
replace LD92NINI = . if (LD92NINI <= -4 )
replace LD94NINI = . if (LD94NINI <= -4 )
replace LD96NINI = . if (LD96NINI <= -4 )
replace LD88CON3 = . if (LD88CON3 <= -4 )
replace LD90CON3 = . if (LD90CON3 <= -4 )
replace LD92CON3 = . if (LD92CON3 <= -4 )
replace LD94CON3 = . if (LD94CON3 <= -4 )
replace LD96CON3 = . if (LD96CON3 <= -4 )
replace LD88AVAI = . if (LD88AVAI <= -4 )
replace LD90AVAI = . if (LD90AVAI <= -4 )
replace LD92AVAI = . if (LD92AVAI <= -4 )
replace LD94AVAI = . if (LD94AVAI <= -4 )
replace LD96AVAI = . if (LD96AVAI <= -4 )
replace LD88BLCH = . if (LD88BLCH <= -4 )
replace LD90BLCH = . if (LD90BLCH <= -4 )
replace LD92BLCH = . if (LD92BLCH <= -4 )
replace LD94BLCH = . if (LD94BLCH <= -4 )
replace LD96BLCH = . if (LD96BLCH <= -4 )
replace LDINTYR = . if (LDINTYR <= -4 )
replace LDINTSVC = . if (LDINTSVC <= -4 )
replace LDINTNED = . if (LDINTNED <= -4 )
replace LDINTSRC = . if (LDINTSRC <= -4 )
replace LDINTTRT = . if (LDINTTRT <= -4 )
replace LDINTACC = . if (LDINTACC <= -4 )
replace PHARMAVA = . if (PHARMAVA <= -4 )
replace NEEDLEAV = . if (NEEDLEAV <= -4 )
replace DIABAVA = . if (DIABAVA <= -4 )
replace DEALERAV = . if (DEALERAV <= -4 )
replace GALLERAV = . if (GALLERAV <= -4 )
replace AVAIL = . if (AVAIL <= -4 )
replace AVAIL88 = . if (AVAIL88 <= -4 )
replace AVAIL90 = . if (AVAIL90 <= -4 )
replace AVAIL92 = . if (AVAIL92 <= -4 )
replace AVAIL94 = . if (AVAIL94 <= -4 )
replace AVAIL96 = . if (AVAIL96 <= -4 )
replace PHARMUSE = . if (PHARMUSE <= -4 )
replace NEEDLUSE = . if (NEEDLUSE <= -4 )
replace DIABUSE = . if (DIABUSE <= -4 )
replace DLRUSE = . if (DLRUSE <= -4 )
replace GALLERUS = . if (GALLERUS <= -4 )
replace USED = . if (USED <= -4 )
replace USED88 = . if (USED88 <= -4 )
replace USED90 = . if (USED90 <= -4 )
replace USED92 = . if (USED92 <= -4 )
replace USED94 = . if (USED94 <= -4 )
replace USED96 = . if (USED96 <= -4 )
replace NEP = . if (NEP <= -4 )
replace NEP88 = . if (NEP88 <= -4 )
replace NEP90 = . if (NEP90 <= -4 )
replace NEP92 = . if (NEP92 <= -4 )
replace NEP94 = . if (NEP94 <= -4 )
replace NEP96 = . if (NEP96 <= -4 )
replace INTPRO88 = . if (INTPRO88 <= -4 )
replace INTPRO90 = . if (INTPRO90 <= -4 )
replace INTPRO92 = . if (INTPRO92 <= -4 )
replace INTPRO94 = . if (INTPRO94 <= -4 )
replace INTPRO96 = . if (INTPRO96 <= -4 )
replace RCHD88 = . if (RCHD88 <= -4 )
replace RCHD90 = . if (RCHD90 <= -4 )
replace RCHD92 = . if (RCHD92 <= -4 )
replace RCHD94 = . if (RCHD94 <= -4 )
replace RCHD96 = . if (RCHD96 <= -4 )
replace PROGTOT = . if (PROGTOT <= -4 )
replace RCHDTOT = . if (RCHDTOT <= -4 )
replace NORX = . if (NORX <= -4 )
replace DRUGTRTP = . if (DRUGTRTP <= -4 )
replace HIVTESTP = . if (HIVTESTP <= -4 )
replace STDPROG = . if (STDPROG <= -4 )
replace HIVORPRG = . if (HIVORPRG <= -4 )
replace OTHORPRG = . if (OTHORPRG <= -4 )
replace HIVCMPRG = . if (HIVCMPRG <= -4 )
replace OTHCMPRG = . if (OTHCMPRG <= -4 )
replace MEDSVPRG = . if (MEDSVPRG <= -4 )
replace HLPROG = . if (HLPROG <= -4 )
replace OTHINTPR = . if (OTHINTPR <= -4 )
replace DRUGTRTR = . if (DRUGTRTR <= -4 )
replace HIVTESTR = . if (HIVTESTR <= -4 )
replace STDRCHD = . if (STDRCHD <= -4 )
replace HIVORRCH = . if (HIVORRCH <= -4 )
replace OTHORRCH = . if (OTHORRCH <= -4 )
replace HIVCMRCH = . if (HIVCMRCH <= -4 )
replace OTHCMRCH = . if (OTHCMRCH <= -4 )
replace MEDSVRCH = . if (MEDSVRCH <= -4 )
replace HLRCHD = . if (HLRCHD <= -4 )
replace OTHINTR = . if (OTHINTR <= -4 )
replace EARLY = . if (EARLY <= -4 )
replace DESIGN = . if (DESIGN <= -4 )


*/
/********************************************************************

 Section 5: Save Outfile

  This section saves out a Stata system format file.  There is no reason to
  modify it if the macros in Section 1 were specified correctly.

*********************************************************************/

save `outfile', replace

